
" Vim syntax file

" Language:	Altera-TCL/SDC "
" Maintainer:	Paul Zimmer <paulzimmer@zimmerdesignservices.com> "
" Original:	Paul Zimmer <paulzimmer@zimmerdesignservices.com> "
" Version:	11.61 Sun Oct 17 14:30:15 PDT 2010 "
" "
" "


" This flag enables special handling for eval-type commands.  This will
" make the commands following the eval highlight correctly, at some cost
" in performance.
" Default special handling for eval commands on
if ! exists("altera_sta_syntax_enable_eval")
  let altera_sta_syntax_enable_eval = "1"
endif


" For version 5.x: Clear all syntax items
" For version 6.x: Quit when a syntax file was already loaded
"if version < 600  <- got this from somewhere, but it doesn't seem to work
  syntax clear
"elseif exists("b:current_syntax")
"  finish
"endif

" Pull in tcl/tk 
"if version >= 600
"  runtime! syntax/tcl.vim
"else
"  "source <sfile>:p:h/tcl.vim
"  source $VIMRUNTIME/syntax/tcl.vim
"endif

"" Remove some tcl/tk groups that don't apply or will be overridden 
""Use my definition for commands, they have ^|[ start requirement
"syntax clear tcltkCommand 
"syntax clear tclString 
""These don't exist in command-line tcl
"syntax clear tcltkWidgetSwitch 
"syntax clear tcltkWidgetColor


setlocal iskeyword+=-,_,&  " - _ and & need to be allowed in keywords


" *****************************************************************
"
"   Variable names
syn match tclVarRef "$\(::\)\?[_a-zA-Z-][a-zA-Z0-9_.()-]*"
syn match tclVarRef "${\(::\)\?[_a-zA-Z-][a-zA-Z0-9_.()-]*}"

"   Comments (allow comments at end of line following ; )
syn region  tclComment		start=";\s*\#"hs=s+1 end="[^\\]$"lc=1 contains=tclTodo
syn region  tclComment		start="^\s*\#"hs=s end="[^\\]$"lc=1 contains=tclTodo
"
"   Todo (from tcl.vim)
syn keyword tclTodo contained TODO

" Allow - in numbers
"integer number, or floating point number without a dot and with "f".
syn case ignore
syn match  tclNumber		"\<\%[-]\d\+\(u\=l\=\|lu\|f\)\>"
"floating point number, with dot, optional exponent
syn match  tclNumber		"\<\%[-]\d\+\.\d*\(e[-+]\=\d\+\)\=[fl]\=\>"
"floating point number, starting with a dot, optional exponent
syn match  tclNumber		"\%[-]\.\d\+\(e[-+]\=\d\+\)\=[fl]\=\>"
"floating point number, without dot, with exponent
syn match  tclNumber		"\<\%[-]\d\+e[-+]\=\d\+[fl]\=\>"
"hex number
syn match  tclNumber		"0x[0-9a-f]\+\(u\=l\=\|lu\)\>"
syn case match

" Taken from tcl.vim dated 2006 Nov 17
" String and Character contstants
" Highlight special characters (those which have a backslash) differently
syn match   tclSpecial contained "\\\d\d\d\=\|\\."
" A string needs the skip argument as it may legitimately contain \".
" Match at start of line
syn region  tclString		  start=+^"+ end=+"+ contains=tclSpecial skip=+\\\\\|\\"+
"Match all other legal strings.
syn region  tclString		  start=+[^\\]"+ms=s+1  end=+"+ contains=tclSpecial skip=+\\\\\|\\"+

" Match ordinary busses (ex: data[10])
syn match Bus "\[\d\+\]"

" Match busses with variables for bit locations (ex: data[$bit])
syn region Bus start="\[$\(::\)\?[_a-zA-Z-][a-zA-Z0-9_.()-]*"rs=s+1  end="\]"me=e,he=e contains=tclVarRef
syn region Bus start="\[${\(::\)\?[_a-zA-Z-][a-zA-Z0-9_.()-]*}"rs=s+1  end="\]"me=e,he=e contains=tclVarRef


" *****************************************************************

"Create a cluster for the std contains items to save space
syn cluster altera_stacontainscluster contains=tclLineContinue,tclNumber,tclVarRef,tclString,tcltkCommand,tclComment,ResVarRef,Bus


" The rest is generated by a perl script running over:
"    altera pdf file DA6C91A6d01.txt
"    altera help file altera_sdc_help.txt



" Attributes
syn keyword altera_sta_attributes contained 
hi! link altera_sta_attributes Structure

" Built-in Variables

" Commands
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<add_cmd_to_tcl_table_menu\>" start="[\[{]\s*\<add_cmd_to_tcl_table_menu\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<add_ddr_report_command\>" start="[\[{]\s*\<add_ddr_report_command\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn keyword altera_staadd_row_to_table contained -h[] -he[lp] -i[d] -l[ong_help] -n[ame] 
hi! link altera_staadd_row_to_table Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<add_row_to_table\>" start="[\[{]\s*\<add_row_to_table\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staadd_row_to_table

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<add_timing_summary_data\>" start="[\[{]\s*\<add_timing_summary_data\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn keyword altera_staadd_to_collection contained -h[] -he[lp] -l[ong_help] 
hi! link altera_staadd_to_collection Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<add_to_collection\>" start="[\[{]\s*\<add_to_collection\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staadd_to_collection

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<add_to_recent_projects\>" start="[\[{]\s*\<add_to_recent_projects\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<add_to_recent_projects_internal\>" start="[\[{]\s*\<add_to_recent_projects_internal\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<after\>" start="[\[{]\s*\<after\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn keyword altera_staall_clocks contained -h[] -he[lp] -l[ong_help] b[oolean] f[loat] i[nt] l[ist] m[erge_duplicates] on[e_of_string] op[tional] rem[ainder] req[uired] s[tring] value_[help] values[] 
hi! link altera_staall_clocks Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<all_clocks\>" start="[\[{]\s*\<all_clocks\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staall_clocks

syn keyword altera_staall_inputs contained -h[] -he[lp] -l[ong_help] 
hi! link altera_staall_inputs Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<all_inputs\>" start="[\[{]\s*\<all_inputs\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staall_inputs

syn keyword altera_staall_outputs contained -h[] -he[lp] -l[ong_help] 
hi! link altera_staall_outputs Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<all_outputs\>" start="[\[{]\s*\<all_outputs\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staall_outputs

syn keyword altera_staall_registers contained -h[] -he[lp] -l[ong_help] 
hi! link altera_staall_registers Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<all_registers\>" start="[\[{]\s*\<all_registers\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staall_registers

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<append\>" start="[\[{]\s*\<append\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<apply\>" start="[\[{]\s*\<apply\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn keyword altera_staarray contained a[nymore] d[onesearch] e[xists] g[et] na[mes] ne[xtelement] se[t] si[ze] star[tsearch] stat[istics] u[nset] 
hi! link altera_staarray Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<array\>" start="[\[{]\s*\<array\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staarray

syn keyword altera_staassignment_group contained -add_e[xception] -add_m[ember] -c[omment] -d[isable] -get_e[xceptions] -get_m[embers] -h[] -he[lp] -l[ong_help] -o[verwrite] -remove[] -remove_e[xception] -remove_m[ember] -t[ag] 
hi! link altera_staassignment_group Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<assignment_group\>" start="[\[{]\s*\<assignment_group\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staassignment_group

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<auto_execok\>" start="[\[{]\s*\<auto_execok\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<auto_import\>" start="[\[{]\s*\<auto_import\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<auto_load\>" start="[\[{]\s*\<auto_load\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<auto_load_index\>" start="[\[{]\s*\<auto_load_index\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<auto_mkindex\>" start="[\[{]\s*\<auto_mkindex\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<auto_mkindex_old\>" start="[\[{]\s*\<auto_mkindex_old\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<auto_qualify\>" start="[\[{]\s*\<auto_qualify\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<auto_reset\>" start="[\[{]\s*\<auto_reset\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<binary\>" start="[\[{]\s*\<binary\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<break\>" start="[\[{]\s*\<break\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<build_tcl_table_cmd\>" start="[\[{]\s*\<build_tcl_table_cmd\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<case\>" start="[\[{]\s*\<case\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<catch\>" start="[\[{]\s*\<catch\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<cd\>" start="[\[{]\s*\<cd\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<chan\>" start="[\[{]\s*\<chan\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn keyword altera_stacheck_timing contained -a[ppend] -f[ile] -h[] -he[lp] -i[nclude] -l[ong_help] -p[anel_name] -s[tdout] 
hi! link altera_stacheck_timing Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<check_timing\>" start="[\[{]\s*\<check_timing\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_stacheck_timing

syn keyword altera_stachecksum contained -a[lgorithm] -h[] -he[lp] -l[ong_help] 
hi! link altera_stachecksum Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<checksum\>" start="[\[{]\s*\<checksum\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_stachecksum

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<clock\>" start="[\[{]\s*\<clock\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<close\>" start="[\[{]\s*\<close\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<close_timing_report\>" start="[\[{]\s*\<close_timing_report\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<concat\>" start="[\[{]\s*\<concat\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<continue\>" start="[\[{]\s*\<continue\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<copy_project\>" start="[\[{]\s*\<copy_project\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<copy_project_for_hardcopy\>" start="[\[{]\s*\<copy_project_for_hardcopy\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn keyword altera_stacreate_clock contained -a[dd] -h[] -he[lp] -l[ong_help] -n[ame] -p[eriod] -w[aveform] 
hi! link altera_stacreate_clock Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<create_clock\>" start="[\[{]\s*\<create_clock\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_stacreate_clock

syn keyword altera_stacreate_generated_clock contained -a[dd] -di[vide_by] -du[ty_cycle] -edge_[shift] -edges[] -h[] -he[lp] -i[nvert] -l[ong_help] -ma[ster_clock] -mu[ltiply_by] -n[ame] -o[ffset] -p[hase] -s[ource] 
hi! link altera_stacreate_generated_clock Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<create_generated_clock\>" start="[\[{]\s*\<create_generated_clock\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_stacreate_generated_clock

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<create_pin_object\>" start="[\[{]\s*\<create_pin_object\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn keyword altera_stacreate_report_histogram contained -color_d[iv] -color_l[ist] -h[] -he[lp] -l[ong_help] -ma[x_data] -mi[n_data] -n[um_bins] -p[anel_name] -x_l[abel] -x_u[nit] -y[_label] 
hi! link altera_stacreate_report_histogram Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<create_report_histogram\>" start="[\[{]\s*\<create_report_histogram\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_stacreate_report_histogram

syn keyword altera_stacreate_report_panel contained -f[older] -h[] -he[lp] -l[ong_help] -t[able] 
hi! link altera_stacreate_report_panel Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<create_report_panel\>" start="[\[{]\s*\<create_report_panel\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_stacreate_report_panel

syn keyword altera_stacreate_revision contained -b[ased_on] -c[opy_results] -h[] -he[lp] -l[ong_help] -s[et_current] 
hi! link altera_stacreate_revision Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<create_revision\>" start="[\[{]\s*\<create_revision\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_stacreate_revision

syn keyword altera_stacreate_slack_histogram contained -a[ppend] -c[lock_name] -f[ile] -h[] -he[lp] -ho[ld] -l[ong_help] -ma[x_slack] -mi[n_slack] -n[um_bins] -p[anel_name] -rec[overy] -rem[oval] -se[tup] -st[dout] 
hi! link altera_stacreate_slack_histogram Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<create_slack_histogram\>" start="[\[{]\s*\<create_slack_histogram\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_stacreate_slack_histogram

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<create_test_collection\>" start="[\[{]\s*\<create_test_collection\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<create_timequest_summary\>" start="[\[{]\s*\<create_timequest_summary\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<create_timing_database\>" start="[\[{]\s*\<create_timing_database\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn keyword altera_stacreate_timing_netlist contained -f[orce_dat] -g[rade] -h[] -he[lp] -l[ong_help] -m[odel] -n[o_latch] -p[ost_map] -s[peed] -t[emperature] -v[oltage] -z[ero_ic_delays] 
hi! link altera_stacreate_timing_netlist Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<create_timing_netlist\>" start="[\[{]\s*\<create_timing_netlist\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_stacreate_timing_netlist

syn keyword altera_stacreate_timing_summary contained -a[ppend] -f[ile] -h[] -he[lp] -ho[ld] -l[ong_help] -m[pw] -p[anel_name] -rec[overy] -rem[oval] -se[tup] -st[dout] 
hi! link altera_stacreate_timing_summary Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<create_timing_summary\>" start="[\[{]\s*\<create_timing_summary\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_stacreate_timing_summary

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<current_design\>" start="[\[{]\s*\<current_design\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<current_instance\>" start="[\[{]\s*\<current_instance\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn keyword altera_stadefine_proc_attributes contained b[oolean] f[loat] i[nt] l[ist] m[erge_duplicates] on[e_of_string] op[tional] rem[ainder] req[uired] s[tring] value_[help] values[] 
hi! link altera_stadefine_proc_attributes Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<define_proc_attributes\>" start="[\[{]\s*\<define_proc_attributes\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_stadefine_proc_attributes

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<delete_folder\>" start="[\[{]\s*\<delete_folder\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn keyword altera_stadelete_report_panel contained -h[] -he[lp] -i[d] -l[ong_help] -n[ame] 
hi! link altera_stadelete_report_panel Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<delete_report_panel\>" start="[\[{]\s*\<delete_report_panel\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_stadelete_report_panel

syn keyword altera_stadelete_revision contained -h[] -he[lp] -l[ong_help] 
hi! link altera_stadelete_revision Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<delete_revision\>" start="[\[{]\s*\<delete_revision\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_stadelete_revision

syn keyword altera_stadelete_timing_netlist contained -h[] -he[lp] -l[ong_help] 
hi! link altera_stadelete_timing_netlist Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<delete_timing_netlist\>" start="[\[{]\s*\<delete_timing_netlist\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_stadelete_timing_netlist

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<delete_timing_report_panel\>" start="[\[{]\s*\<delete_timing_report_panel\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn keyword altera_staderive_clock_uncertainty contained -a[dd] -h[] -he[lp] -l[ong_help] -o[verwrite] 
hi! link altera_staderive_clock_uncertainty Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<derive_clock_uncertainty\>" start="[\[{]\s*\<derive_clock_uncertainty\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staderive_clock_uncertainty

syn keyword altera_staderive_clocks contained -h[] -he[lp] -l[ong_help] -p[eriod] -w[aveform] 
hi! link altera_staderive_clocks Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<derive_clocks\>" start="[\[{]\s*\<derive_clocks\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staderive_clocks

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<derive_lvds_clocks\>" start="[\[{]\s*\<derive_lvds_clocks\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn keyword altera_staderive_pll_clocks contained -c[reate_base_clocks] -h[] -he[lp] -l[ong_help] -u[se_tan_name] 
hi! link altera_staderive_pll_clocks Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<derive_pll_clocks\>" start="[\[{]\s*\<derive_pll_clocks\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staderive_pll_clocks

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<destroy_pin_object\>" start="[\[{]\s*\<destroy_pin_object\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<dict\>" start="[\[{]\s*\<dict\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<disable_msg_box\>" start="[\[{]\s*\<disable_msg_box\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn keyword altera_stadisable_natural_bus_naming contained -h[] -he[lp] -l[ong_help] 
hi! link altera_stadisable_natural_bus_naming Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<disable_natural_bus_naming\>" start="[\[{]\s*\<disable_natural_bus_naming\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_stadisable_natural_bus_naming

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<disable_natural_bus_naming_internal\>" start="[\[{]\s*\<disable_natural_bus_naming_internal\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<echo_time\>" start="[\[{]\s*\<echo_time\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<else\>" start="[\[{]\s*\<else\>"hs=s+1 start="\}\s*\<else\>"hs=s+1 matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<elseif\>" start="[\[{]\s*\<elseif\>"hs=s+1 start="\}\s*\<elseif\>"hs=s+1 matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn keyword altera_staenable_ccpp_removal contained -d[epth] -h[] -he[lp] -l[ong_help] -of[f] -on[] 
hi! link altera_staenable_ccpp_removal Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<enable_ccpp_removal\>" start="[\[{]\s*\<enable_ccpp_removal\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staenable_ccpp_removal

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<enable_msg_box\>" start="[\[{]\s*\<enable_msg_box\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn keyword altera_staenable_natural_bus_naming contained -h[] -he[lp] -l[ong_help] 
hi! link altera_staenable_natural_bus_naming Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<enable_natural_bus_naming\>" start="[\[{]\s*\<enable_natural_bus_naming\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staenable_natural_bus_naming

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<enable_natural_bus_naming_internal\>" start="[\[{]\s*\<enable_natural_bus_naming_internal\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn keyword altera_staenable_sdc_extension_collections contained -h[] -he[lp] -l[ong_help] -of[f] -on[] 
hi! link altera_staenable_sdc_extension_collections Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<enable_sdc_extension_collections\>" start="[\[{]\s*\<enable_sdc_extension_collections\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staenable_sdc_extension_collections

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<encoding\>" start="[\[{]\s*\<encoding\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<enumerate_family_traits\>" start="[\[{]\s*\<enumerate_family_traits\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<eof\>" start="[\[{]\s*\<eof\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<error\>" start="[\[{]\s*\<error\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn keyword altera_staescape_brackets contained -h[] -he[lp] -l[ong_help] 
hi! link altera_staescape_brackets Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<escape_brackets\>" start="[\[{]\s*\<escape_brackets\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staescape_brackets

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<escape_brackets_internal\>" start="[\[{]\s*\<escape_brackets_internal\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<eval\>" start="[\[{]\s*\<eval\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,tcltkCommandForEval

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<exec\>" start="[\[{]\s*\<exec\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn keyword altera_staexecute_assignment_batch contained -h[] -he[lp] -l[ong_help] 
hi! link altera_staexecute_assignment_batch Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<execute_assignment_batch\>" start="[\[{]\s*\<execute_assignment_batch\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staexecute_assignment_batch

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<exit\>" start="[\[{]\s*\<exit\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<export_assignment_files\>" start="[\[{]\s*\<export_assignment_files\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn keyword altera_staexport_assignments contained -h[] -he[lp] -l[ong_help] -r[eorganize] 
hi! link altera_staexport_assignments Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<export_assignments\>" start="[\[{]\s*\<export_assignments\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staexport_assignments

syn keyword altera_staexpr contained ab[s] ac[os] as[in] atan[] atan2[] ce[il] cos[] cosh[] d[ouble] e[xp] fl[oor] fm[od] h[ypot] i[nt] log[] log1[0] p[ow] r[ound] sin[] sinh[] sq[rt] tan[] tanh[] 
hi! link altera_staexpr Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<expr\>" start="[\[{]\s*\<expr\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staexpr

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<fblocked\>" start="[\[{]\s*\<fblocked\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<fconfigure\>" start="[\[{]\s*\<fconfigure\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<fcopy\>" start="[\[{]\s*\<fcopy\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn keyword altera_stafile contained -f[orce] ati[me] att[ributes] ch[annels] co[py] de[lete] di[rname] exe[cutable] exi[sts] ext[ension] isd[irectory] isf[ile] j[oin] li[nk] ls[tat] mk[dir] mt[ime] na[tivename] no[rmalize] o[wned] p[athtype] reada[ble] readl[ink] ren[ame] ro[otname] se[parator] si[ze] sp[lit] st[at] sy[stem] ta[il] ty[pe] v[olumes] w[ritable] 
hi! link altera_stafile Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<file\>" start="[\[{]\s*\<file\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_stafile

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<fileevent\>" start="[\[{]\s*\<fileevent\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<find_intersection\>" start="[\[{]\s*\<find_intersection\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<flush\>" start="[\[{]\s*\<flush\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<for\>" start="[\[{]\s*\<for\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<foreach\>" start="[\[{]\s*\<foreach\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<foreach_in_collection\>" start="[\[{]\s*\<foreach_in_collection\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<format\>" start="[\[{]\s*\<format\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<get_acf_info\>" start="[\[{]\s*\<get_acf_info\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<get_acf_manager\>" start="[\[{]\s*\<get_acf_manager\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn keyword altera_staget_all_assignment_names contained -f[amily] -h[] -he[lp] -l[ong_help] -m[odule] -t[ype] 
hi! link altera_staget_all_assignment_names Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<get_all_assignment_names\|get_all_assignment_name\>" start="[\[{]\s*\<get_all_assignment_names\|get_all_assignment_name\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staget_all_assignment_names

syn keyword altera_staget_all_assignments contained -e[ntity] -f[rom] -h[] -he[lp] -l[ong_help] -n[ame] -s[ection_id] -ta[g] -to[] -ty[pe] 
hi! link altera_staget_all_assignments Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<get_all_assignments\|get_all_assignment\>" start="[\[{]\s*\<get_all_assignments\|get_all_assignment\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staget_all_assignments

syn keyword altera_staget_all_global_assignments contained -e[ntity] -h[] -he[lp] -l[ong_help] -n[ame] -s[ection_id] -t[ag] 
hi! link altera_staget_all_global_assignments Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<get_all_global_assignments\|get_all_global_assignment\>" start="[\[{]\s*\<get_all_global_assignments\|get_all_global_assignment\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staget_all_global_assignments

syn keyword altera_staget_all_instance_assignments contained -e[ntity] -f[rom] -h[] -he[lp] -l[ong_help] -n[ame] -s[ection_id] -ta[g] -to[] 
hi! link altera_staget_all_instance_assignments Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<get_all_instance_assignments\|get_all_instance_assignment\>" start="[\[{]\s*\<get_all_instance_assignments\|get_all_instance_assignment\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staget_all_instance_assignments

syn keyword altera_staget_all_parameters contained -e[ntity] -h[] -he[lp] -l[ong_help] -n[ame] -ta[g] -to[] 
hi! link altera_staget_all_parameters Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<get_all_parameters\|get_all_parameter\>" start="[\[{]\s*\<get_all_parameters\|get_all_parameter\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staget_all_parameters

syn keyword altera_staget_all_quartus_defaults contained -h[] -he[lp] -l[ong_help] -n[ame] -s[ection_id] 
hi! link altera_staget_all_quartus_defaults Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<get_all_quartus_defaults\|get_all_quartus_default\>" start="[\[{]\s*\<get_all_quartus_defaults\|get_all_quartus_default\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staget_all_quartus_defaults

syn keyword altera_staget_all_user_option_names contained -h[] -he[lp] -l[ong_help] -n[ame] 
hi! link altera_staget_all_user_option_names Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<get_all_user_option_names\|get_all_user_option_name\>" start="[\[{]\s*\<get_all_user_option_names\|get_all_user_option_name\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staget_all_user_option_names

syn keyword altera_staget_assignment_groups contained -h[] -he[lp] -k[eepers] -l[ong_help] -p[orts] -r[egisters] 
hi! link altera_staget_assignment_groups Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<get_assignment_groups\|get_assignment_group\>" start="[\[{]\s*\<get_assignment_groups\|get_assignment_group\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staget_assignment_groups

syn keyword altera_staget_assignment_info contained -e[ntity] -f[rom] -g[et_tcl_command] -h[] -he[lp] -l[ong_help] -n[ame] -s[ection_id] -ta[g] -to[] -v[alue] 
hi! link altera_staget_assignment_info Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<get_assignment_info\|get_assignment_info\>" start="[\[{]\s*\<get_assignment_info\|get_assignment_info\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staget_assignment_info

syn keyword altera_staget_assignment_name_info contained -h[] -he[lp] -l[ong_help] 
hi! link altera_staget_assignment_name_info Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<get_assignment_name_info\|get_assignment_name_info\>" start="[\[{]\s*\<get_assignment_name_info\|get_assignment_name_info\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staget_assignment_name_info

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<get_assignments_for_name_id\|get_assignments_for_name_id\>" start="[\[{]\s*\<get_assignments_for_name_id\|get_assignments_for_name_id\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn keyword altera_staget_available_operating_conditions contained -a[ll] -h[] -he[lp] -l[ong_help] 
hi! link altera_staget_available_operating_conditions Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<get_available_operating_conditions\|get_available_operating_condition\>" start="[\[{]\s*\<get_available_operating_conditions\|get_available_operating_condition\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staget_available_operating_conditions

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<get_bit_settings\|get_bit_setting\>" start="[\[{]\s*\<get_bit_settings\|get_bit_setting\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<get_board_model_parameter\>" start="[\[{]\s*\<get_board_model_parameter\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<get_board_model_parameter_list\|get_board_model_parameter_list\>" start="[\[{]\s*\<get_board_model_parameter_list\|get_board_model_parameter_list\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn keyword altera_staget_cell_info contained -buried_n[odes] -buried_r[egs] -h[] -he[lp] -in_pin_[names] -in_pins[] -loc[ation] -lon[g_help] -n[ame] -out_pin_[names] -out_pins[] -pin_[names] -pins[] -t[ype] -w[ysiwyg_type] 
hi! link altera_staget_cell_info Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<get_cell_info\>" start="[\[{]\s*\<get_cell_info\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staget_cell_info

syn keyword altera_staget_cells contained -c[ompatibility_mode] -h[] -he[lp] -hi[erarchical] -l[ong_help] -no_[duplicates] -noc[ase] -now[arn] 
hi! link altera_staget_cells Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<get_cells\|get_cell\>" start="[\[{]\s*\<get_cells\|get_cell\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staget_cells

syn keyword altera_staget_clock_domain_info contained -h[] -he[lp] -ho[ld] -l[ong_help] -m[pw] -rec[overy] -rem[oval] -s[etup] 
hi! link altera_staget_clock_domain_info Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<get_clock_domain_info\>" start="[\[{]\s*\<get_clock_domain_info\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staget_clock_domain_info

syn keyword altera_staget_clock_fmax_info contained -h[] -he[lp] -l[ong_help] 
hi! link altera_staget_clock_fmax_info Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<get_clock_fmax_info\>" start="[\[{]\s*\<get_clock_fmax_info\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staget_clock_fmax_info

syn keyword altera_staget_clock_info contained -di[vide_by] -du[ty_cycle] -edge_[shifts] -edges[] -f[all] -h[] -he[lp] -i[s_inverted] -la[tency] -lo[ng_help] -master_clock[] -master_clock_[pin] -max[] -mi[n] -mu[ltiply_by] -na[me] -nreg_n[eg] -nreg_p[os] -o[ffset] -pe[riod] -ph[ase] -r[ise] -ta[rgets] -ty[pe] -w[aveform] 
hi! link altera_staget_clock_info Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<get_clock_info\>" start="[\[{]\s*\<get_clock_info\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staget_clock_info

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<get_clock_list\|get_clock_list\>" start="[\[{]\s*\<get_clock_list\|get_clock_list\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn keyword altera_staget_clocks contained -h[] -he[lp] -l[ong_help] -noc[ase] -now[arn] 
hi! link altera_staget_clocks Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<get_clocks\|get_clock\>" start="[\[{]\s*\<get_clocks\|get_clock\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staget_clocks

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<get_collection_by_name\>" start="[\[{]\s*\<get_collection_by_name\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<get_collection_info\>" start="[\[{]\s*\<get_collection_info\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn keyword altera_staget_collection_size contained -h[] -he[lp] -l[ong_help] 
hi! link altera_staget_collection_size Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<get_collection_size\|get_collection_size\>" start="[\[{]\s*\<get_collection_size\|get_collection_size\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staget_collection_size

syn keyword altera_staget_current_revision contained -h[] -he[lp] -l[ong_help] 
hi! link altera_staget_current_revision Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<get_current_revision\|get_current_revision\>" start="[\[{]\s*\<get_current_revision\|get_current_revision\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staget_current_revision

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<get_current_sta_report_folder\|get_current_sta_report_folder\>" start="[\[{]\s*\<get_current_sta_report_folder\|get_current_sta_report_folder\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<get_current_strength\|get_current_strength\>" start="[\[{]\s*\<get_current_strength\|get_current_strength\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<get_current_strength_list\|get_current_strength_list\>" start="[\[{]\s*\<get_current_strength_list\|get_current_strength_list\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<get_current_timequest_report_folder\|get_current_timequest_report_folder\>" start="[\[{]\s*\<get_current_timequest_report_folder\|get_current_timequest_report_folder\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn keyword altera_staget_datasheet contained -h[] -he[lp] -l[ong_help] 
hi! link altera_staget_datasheet Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<get_datasheet\|get_datasheet\>" start="[\[{]\s*\<get_datasheet\|get_datasheet\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staget_datasheet

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<get_datasheet_report_panel_name\|get_datasheet_report_panel_name\>" start="[\[{]\s*\<get_datasheet_report_panel_name\|get_datasheet_report_panel_name\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn keyword altera_staget_default_sdc_file_names contained -h[] -he[lp] -l[ong_help] 
hi! link altera_staget_default_sdc_file_names Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<get_default_sdc_file_names\|get_default_sdc_file_name\>" start="[\[{]\s*\<get_default_sdc_file_names\|get_default_sdc_file_name\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staget_default_sdc_file_names

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<get_delay_chain\>" start="[\[{]\s*\<get_delay_chain\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<get_delay_info\>" start="[\[{]\s*\<get_delay_info\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<get_dq_width\>" start="[\[{]\s*\<get_dq_width\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<get_dstr_string\|get_dstr_string\>" start="[\[{]\s*\<get_dstr_string\|get_dstr_string\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn keyword altera_staget_edge_info contained -delay[] -delay_[type] -ds[t] -ff[] -fr[] -h[] -he[lp] -l[ong_help] -ma[x] -mi[n] -n[ame] -rf[] -rr[] -s[rc] -t[ype] -u[nateness] 
hi! link altera_staget_edge_info Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<get_edge_info\>" start="[\[{]\s*\<get_edge_info\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staget_edge_info

syn keyword altera_staget_edge_slacks contained -h[] -he[lp] -ho[ld] -l[ong_help] -rec[overy] -rem[oval] -s[etup] 
hi! link altera_staget_edge_slacks Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<get_edge_slacks\|get_edge_slack\>" start="[\[{]\s*\<get_edge_slacks\|get_edge_slack\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staget_edge_slacks

syn keyword altera_staget_environment_info contained -h[] -he[lp] -l[ong_help] -num_l[ogical_processors] -num_p[hysical_processors] -o[perating_system] 
hi! link altera_staget_environment_info Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<get_environment_info\>" start="[\[{]\s*\<get_environment_info\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staget_environment_info

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<get_family_info\>" start="[\[{]\s*\<get_family_info\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn keyword altera_staget_family_list contained -h[] -he[lp] -l[ong_help] 
hi! link altera_staget_family_list Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<get_family_list\|get_family_list\>" start="[\[{]\s*\<get_family_list\|get_family_list\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staget_family_list

syn keyword altera_staget_fanins contained -a[synch] -c[lock] -h[] -he[lp] -i[nverting_paths] -l[ong_help] -no_[logic] -non[_inverting_paths] -s[ynch] -t[hrough] 
hi! link altera_staget_fanins Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<get_fanins\|get_fanin\>" start="[\[{]\s*\<get_fanins\|get_fanin\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staget_fanins

syn keyword altera_staget_fanouts contained -h[] -he[lp] -i[nverting_paths] -l[ong_help] -no_[logic] -non[_inverting_paths] -t[hrough] 
hi! link altera_staget_fanouts Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<get_fanouts\|get_fanout\>" start="[\[{]\s*\<get_fanouts\|get_fanout\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staget_fanouts

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<get_file_info\>" start="[\[{]\s*\<get_file_info\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<get_files\|get_file\>" start="[\[{]\s*\<get_files\|get_file\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn keyword altera_staget_fitter_resource_usage contained -alm[] -alu[t] -av[ailable] -h[] -he[lp] -i[o_pin] -la[b] -le[] -lo[ng_help] -m[em_bit] -p[ercentage] -r[eg] -us[ed] -ut[ilization] 
hi! link altera_staget_fitter_resource_usage Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<get_fitter_resource_usage\|get_fitter_resource_usage\>" start="[\[{]\s*\<get_fitter_resource_usage\|get_fitter_resource_usage\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staget_fitter_resource_usage

syn keyword altera_staget_global_assignment contained -e[ntity] -f[ront] -h[] -he[lp] -l[ong_help] -n[ame] -s[ection_id] -t[ag] 
hi! link altera_staget_global_assignment Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<get_global_assignment\|get_global_assignment\>" start="[\[{]\s*\<get_global_assignment\|get_global_assignment\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staget_global_assignment

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<get_ini_file\>" start="[\[{]\s*\<get_ini_file\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<get_ini_var\>" start="[\[{]\s*\<get_ini_var\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<get_input_timing_results\|get_input_timing_result\>" start="[\[{]\s*\<get_input_timing_results\|get_input_timing_result\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn keyword altera_staget_instance_assignment contained -e[ntity] -from[] -fron[t] -h[] -he[lp] -l[ong_help] -n[ame] -s[ection_id] -ta[g] -to[] 
hi! link altera_staget_instance_assignment Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<get_instance_assignment\|get_instance_assignment\>" start="[\[{]\s*\<get_instance_assignment\|get_instance_assignment\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staget_instance_assignment

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<get_io_standard\|get_io_standard\>" start="[\[{]\s*\<get_io_standard\|get_io_standard\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<get_io_standard_list\|get_io_standard_list\>" start="[\[{]\s*\<get_io_standard_list\|get_io_standard_list\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn keyword altera_staget_keepers contained -h[] -he[lp] -l[ong_help] -no_[duplicates] -noc[ase] -now[arn] 
hi! link altera_staget_keepers Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<get_keepers\|get_keeper\>" start="[\[{]\s*\<get_keepers\|get_keeper\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staget_keepers

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<get_lib_cells\|get_lib_cell\>" start="[\[{]\s*\<get_lib_cells\|get_lib_cell\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<get_lib_pins\|get_lib_pin\>" start="[\[{]\s*\<get_lib_pins\|get_lib_pin\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<get_libraries\|get_librarie\>" start="[\[{]\s*\<get_libraries\|get_librarie\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<get_libs\|get_lib\>" start="[\[{]\s*\<get_libs\|get_lib\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<get_license_xml\|get_license_xml\>" start="[\[{]\s*\<get_license_xml\|get_license_xml\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<get_location\>" start="[\[{]\s*\<get_location\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn keyword altera_staget_location_assignment contained -h[] -he[lp] -l[ong_help] -ta[g] -to[] 
hi! link altera_staget_location_assignment Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<get_location_assignment\|get_location_assignment\>" start="[\[{]\s*\<get_location_assignment\|get_location_assignment\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staget_location_assignment

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<get_max_skew_default_include_list\|get_max_skew_default_include_list\>" start="[\[{]\s*\<get_max_skew_default_include_list\|get_max_skew_default_include_list\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn keyword altera_staget_min_pulse_width contained -h[] -he[lp] -l[ong_help] -n[worst] 
hi! link altera_staget_min_pulse_width Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<get_min_pulse_width\|get_min_pulse_width\>" start="[\[{]\s*\<get_min_pulse_width\|get_min_pulse_width\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staget_min_pulse_width

syn keyword altera_staget_name_info contained -h[] -he[lp] -i[nfo] -l[ong_help] -o[bservable_type] 
hi! link altera_staget_name_info Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<get_name_info\>" start="[\[{]\s*\<get_name_info\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staget_name_info

syn keyword altera_staget_names contained -e[ntity] -f[ilter] -h[] -he[lp] -li[brary] -lo[ng_help] -n[ode_type] -o[bservable_type] 
hi! link altera_staget_names Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<get_names\|get_name\>" start="[\[{]\s*\<get_names\|get_name\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_sta_attributes,altera_staget_names

syn keyword altera_staget_net_info contained -h[] -he[lp] -l[ong_help] -n[ame] -p[in] -t[ype] 
hi! link altera_staget_net_info Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<get_net_info\>" start="[\[{]\s*\<get_net_info\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staget_net_info

syn keyword altera_staget_nets contained -h[] -he[lp] -l[ong_help] -no_[duplicates] -noc[ase] -now[arn] 
hi! link altera_staget_nets Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<get_nets\|get_net\>" start="[\[{]\s*\<get_nets\|get_net\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staget_nets

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<get_node_clock_list\|get_node_clock_list\>" start="[\[{]\s*\<get_node_clock_list\|get_node_clock_list\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn keyword altera_staget_node_info contained -a[synch_edges] -ce[ll] -cl[ock_edges] -f[anout_edges] -h[] -he[lp] -loc[ation] -lon[g_help] -n[ame] -s[ynch_edges] -t[ype] 
hi! link altera_staget_node_info Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<get_node_info\>" start="[\[{]\s*\<get_node_info\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staget_node_info

syn keyword altera_staget_nodes contained -h[] -he[lp] -l[ong_help] -no_[duplicates] -noc[ase] -now[arn] 
hi! link altera_staget_nodes Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<get_nodes\|get_node\>" start="[\[{]\s*\<get_nodes\|get_node\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staget_nodes

syn keyword altera_staget_number_of_columns contained -h[] -he[lp] -i[d] -l[ong_help] -n[ame] 
hi! link altera_staget_number_of_columns Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<get_number_of_columns\|get_number_of_column\>" start="[\[{]\s*\<get_number_of_columns\|get_number_of_column\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staget_number_of_columns

syn keyword altera_staget_number_of_rows contained -h[] -he[lp] -i[d] -l[ong_help] -n[ame] 
hi! link altera_staget_number_of_rows Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<get_number_of_rows\|get_number_of_row\>" start="[\[{]\s*\<get_number_of_rows\|get_number_of_row\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staget_number_of_rows

syn keyword altera_staget_object_info contained -h[] -he[lp] -l[ong_help] -n[ame] -t[ype] 
hi! link altera_staget_object_info Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<get_object_info\>" start="[\[{]\s*\<get_object_info\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staget_object_info

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<get_oct_impedance\>" start="[\[{]\s*\<get_oct_impedance\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<get_oct_impedance_list\|get_oct_impedance_list\>" start="[\[{]\s*\<get_oct_impedance_list\|get_oct_impedance_list\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<get_open_drain\>" start="[\[{]\s*\<get_open_drain\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn keyword altera_staget_operating_conditions contained -h[] -he[lp] -l[ong_help] 
hi! link altera_staget_operating_conditions Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<get_operating_conditions\|get_operating_condition\>" start="[\[{]\s*\<get_operating_conditions\|get_operating_condition\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staget_operating_conditions

syn keyword altera_staget_operating_conditions_info contained -d[isplay_name] -g[rade] -h[] -he[lp] -l[ong_help] -m[odel] -n[ame] -s[peed] -t[emperature] -v[oltage] 
hi! link altera_staget_operating_conditions_info Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<get_operating_conditions_info\|get_operating_conditions_info\>" start="[\[{]\s*\<get_operating_conditions_info\|get_operating_conditions_info\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staget_operating_conditions_info

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<get_output_enable_results\|get_output_enable_result\>" start="[\[{]\s*\<get_output_enable_results\|get_output_enable_result\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn keyword altera_staget_parameter contained -e[ntity] -h[] -he[lp] -l[ong_help] -n[ame] -ta[g] -to[] 
hi! link altera_staget_parameter Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<get_parameter\>" start="[\[{]\s*\<get_parameter\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staget_parameter

syn keyword altera_staget_part_info contained -def[ault_voltage] -dev[ice] -family[] -family_[variant] -h[] -he[lp] -l[ong_help] -pa[ckage] -pi[n_count] -s[peed_grade] -t[emperature_grade] 
hi! link altera_staget_part_info Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<get_part_info\>" start="[\[{]\s*\<get_part_info\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staget_part_info

syn keyword altera_staget_part_list contained -d[evice] -f[amily] -h[] -he[lp] -l[ong_help] -pa[ckage] -pi[n_count] -s[peed_grade] 
hi! link altera_staget_part_list Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<get_part_list\|get_part_list\>" start="[\[{]\s*\<get_part_list\|get_part_list\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staget_part_list

syn keyword altera_staget_partition_info contained -c[hild] -h[] -he[lp] -l[ong_help] -n[ame] -p[arent] -t[ype] 
hi! link altera_staget_partition_info Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<get_partition_info\>" start="[\[{]\s*\<get_partition_info\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staget_partition_info

syn keyword altera_staget_partitions contained -c[ell] -h[] -he[lp] -hi[erarchical] -l[ong_help] -n[ocase] 
hi! link altera_staget_partitions Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<get_partitions\|get_partition\>" start="[\[{]\s*\<get_partitions\|get_partition\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staget_partitions

syn keyword altera_staget_path contained -f[rom] -h[] -he[lp] -l[ong_help] -m[in_path] -np[aths] -nw[orst] -p[airs_only] -s[how_routing] -th[rough] -to[] 
hi! link altera_staget_path Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<get_path\>" start="[\[{]\s*\<get_path\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staget_path

syn keyword altera_staget_path_info contained -arrival_p[oints] -arrival_t[ime] -cc[pp] -clock_r[elationship] -clock_s[kew] -d[ata_delay] -from[] -from_clock[] -from_clock_[is_inverted] -h[] -he[lp] -hold_e[nd_multicycle] -hold_s[tart_multicycle] -lat[ch_time] -lau[nch_time] -lo[ng_help] -n[um_logic_levels] -required_p[oints] -required_t[ime] -setup_e[nd_multicycle] -setup_s[tart_multicycle] -sl[ack] -to[] -to_clock[] -to_clock_[is_inverted] -ty[pe] 
hi! link altera_staget_path_info Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<get_path_info\>" start="[\[{]\s*\<get_path_info\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staget_path_info

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<get_pin_count\>" start="[\[{]\s*\<get_pin_count\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<get_pin_direction\>" start="[\[{]\s*\<get_pin_direction\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn keyword altera_staget_pin_info contained -h[] -he[lp] -is_c[lock_pin] -is_i[n_pin] -is_o[ut_pin] -l[ong_help] -na[me] -ne[t] -p[arent_cell] -s[uffix] -t[ype] 
hi! link altera_staget_pin_info Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<get_pin_info\>" start="[\[{]\s*\<get_pin_info\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staget_pin_info

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<get_pin_location\>" start="[\[{]\s*\<get_pin_location\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<get_pin_location_list\|get_pin_location_list\>" start="[\[{]\s*\<get_pin_location_list\|get_pin_location_list\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<get_pin_name\>" start="[\[{]\s*\<get_pin_name\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn keyword altera_staget_pins contained -c[ompatibility_mode] -h[] -he[lp] -hi[erarchical] -l[ong_help] -no_[duplicates] -noc[ase] -now[arn] 
hi! link altera_staget_pins Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<get_pins\|get_pin\>" start="[\[{]\s*\<get_pins\|get_pin\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staget_pins

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<get_pins_from_gid\|get_pins_from_gid\>" start="[\[{]\s*\<get_pins_from_gid\|get_pins_from_gid\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn keyword altera_staget_point_info contained -e[dge] -h[] -he[lp] -i[ncremental_delay] -loc[ation] -lon[g_help] -no[de] -nu[mber_of_fanout] -r[ise_fall] -to[tal_delay] -ty[pe] 
hi! link altera_staget_point_info Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<get_point_info\>" start="[\[{]\s*\<get_point_info\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staget_point_info

syn keyword altera_staget_port_info contained -e[dge_rate] -h[] -he[lp] -is_ino[ut_port] -is_inp[ut_port] -is_o[utput_port] -l[ong_help] -n[ame] -t[ype] 
hi! link altera_staget_port_info Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<get_port_info\>" start="[\[{]\s*\<get_port_info\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staget_port_info

syn keyword altera_staget_ports contained -h[] -he[lp] -l[ong_help] -noc[ase] -now[arn] 
hi! link altera_staget_ports Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<get_ports\|get_port\>" start="[\[{]\s*\<get_ports\|get_port\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staget_ports

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<get_preemphasis\|get_preemphasi\>" start="[\[{]\s*\<get_preemphasis\|get_preemphasi\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn keyword altera_staget_project_directory contained -h[] -he[lp] -l[ong_help] 
hi! link altera_staget_project_directory Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<get_project_directory\>" start="[\[{]\s*\<get_project_directory\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staget_project_directory

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<get_project_license_status\|get_project_license_statu\>" start="[\[{]\s*\<get_project_license_status\|get_project_license_statu\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn keyword altera_staget_project_revisions contained -h[] -he[lp] -l[ong_help] 
hi! link altera_staget_project_revisions Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<get_project_revisions\|get_project_revision\>" start="[\[{]\s*\<get_project_revisions\|get_project_revision\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staget_project_revisions

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<get_project_settings\|get_project_setting\>" start="[\[{]\s*\<get_project_settings\|get_project_setting\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<get_quartus_legal_string\|get_quartus_legal_string\>" start="[\[{]\s*\<get_quartus_legal_string\|get_quartus_legal_string\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<get_ram_bus_hold\|get_ram_bus_hold\>" start="[\[{]\s*\<get_ram_bus_hold\|get_ram_bus_hold\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn keyword altera_staget_register_info contained -a[synch_edges] -c[lock_edges] -f[anout_edges] -h[] -he[lp] -i[s_latch] -l[ong_help] -n[ame] -s[ynch_edges] -tch[] -tcl[] -tco[] -th[] -tm[in] -ts[u] -ty[pe] 
hi! link altera_staget_register_info Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<get_register_info\|get_register_info\>" start="[\[{]\s*\<get_register_info\|get_register_info\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staget_register_info

syn keyword altera_staget_registers contained -h[] -he[lp] -l[ong_help] -no_[duplicates] -noc[ase] -now[arn] 
hi! link altera_staget_registers Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<get_registers\|get_register\>" start="[\[{]\s*\<get_registers\|get_register\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staget_registers

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<get_report_folder\>" start="[\[{]\s*\<get_report_folder\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn keyword altera_staget_report_panel_column_index contained -h[] -he[lp] -i[d] -l[ong_help] -n[ame] 
hi! link altera_staget_report_panel_column_index Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<get_report_panel_column_index\>" start="[\[{]\s*\<get_report_panel_column_index\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staget_report_panel_column_index

syn keyword altera_staget_report_panel_data contained -col[] -col_[name] -h[] -he[lp] -i[d] -l[ong_help] -n[ame] -row[] -row_[name] 
hi! link altera_staget_report_panel_data Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<get_report_panel_data\>" start="[\[{]\s*\<get_report_panel_data\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staget_report_panel_data

syn keyword altera_staget_report_panel_id contained -h[] -he[lp] -l[ong_help] 
hi! link altera_staget_report_panel_id Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<get_report_panel_id\>" start="[\[{]\s*\<get_report_panel_id\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staget_report_panel_id

syn keyword altera_staget_report_panel_names contained -h[] -he[lp] -l[ong_help] 
hi! link altera_staget_report_panel_names Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<get_report_panel_names\|get_report_panel_name\>" start="[\[{]\s*\<get_report_panel_names\|get_report_panel_name\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staget_report_panel_names

syn keyword altera_staget_report_panel_row contained -h[] -he[lp] -i[d] -l[ong_help] -n[ame] -row[] -row_[name] 
hi! link altera_staget_report_panel_row Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<get_report_panel_row\>" start="[\[{]\s*\<get_report_panel_row\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staget_report_panel_row

syn keyword altera_staget_report_panel_row_index contained -h[] -he[lp] -i[d] -l[ong_help] -n[ame] 
hi! link altera_staget_report_panel_row_index Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<get_report_panel_row_index\>" start="[\[{]\s*\<get_report_panel_row_index\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staget_report_panel_row_index

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<get_reserved_type\|get_reserved_type\>" start="[\[{]\s*\<get_reserved_type\|get_reserved_type\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<get_revision_description\|get_revision_description\>" start="[\[{]\s*\<get_revision_description\|get_revision_description\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<get_simulation_results\|get_simulation_result\>" start="[\[{]\s*\<get_simulation_results\|get_simulation_result\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<get_slack_information_for_partitions\|get_slack_information_for_partition\>" start="[\[{]\s*\<get_slack_information_for_partitions\|get_slack_information_for_partition\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<get_slew_rate\|get_slew_rate\>" start="[\[{]\s*\<get_slew_rate\|get_slew_rate\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<get_temperature_option\>" start="[\[{]\s*\<get_temperature_option\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<get_termination\>" start="[\[{]\s*\<get_termination\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn keyword altera_staget_timing_analysis_summary_results contained -a[ctual] -clock_h[old] -clock_s[etup] -h[] -he[lp] -l[ong_help] -min_tc[o] -min_tp[d] -r[equired] -s[lack] -tc[o] -th[] -tp[d] -ts[u] 
hi! link altera_staget_timing_analysis_summary_results Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<get_timing_analysis_summary_results\|get_timing_analysis_summary_result\>" start="[\[{]\s*\<get_timing_analysis_summary_results\|get_timing_analysis_summary_result\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staget_timing_analysis_summary_results

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<get_timing_info\>" start="[\[{]\s*\<get_timing_info\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn keyword altera_staget_timing_paths contained -d[etail] -fall_f[rom_clock] -fall_t[o_clock] -fals[e_path] -from[] -from_[clock] -h[] -he[lp] -ho[ld] -le[ss_than_slack] -lo[ng_help] -np[aths] -nw[orst] -p[airs_only] -rec[overy] -rem[oval] -rise_f[rom_clock] -rise_t[o_clock] -se[tup] -sh[ow_routing] -th[rough] -to[] -to_[clock] 
hi! link altera_staget_timing_paths Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<get_timing_paths\|get_timing_path\>" start="[\[{]\s*\<get_timing_paths\|get_timing_path\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staget_timing_paths

syn keyword altera_staget_top_level_entity contained -h[] -he[lp] -l[ong_help] 
hi! link altera_staget_top_level_entity Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<get_top_level_entity\>" start="[\[{]\s*\<get_top_level_entity\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staget_top_level_entity

syn keyword altera_staget_user_option contained -h[] -he[lp] -l[ong_help] -n[ame] 
hi! link altera_staget_user_option Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<get_user_option\|get_user_option\>" start="[\[{]\s*\<get_user_option\|get_user_option\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staget_user_option

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<get_vod\>" start="[\[{]\s*\<get_vod\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<get_weak_pullup\>" start="[\[{]\s*\<get_weak_pullup\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<gets\>" start="[\[{]\s*\<gets\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<glob\>" start="[\[{]\s*\<glob\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<global\>" start="[\[{]\s*\<global\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,ResVarName

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<help\>" start="[\[{]\s*\<help\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<highlight_report\>" start="[\[{]\s*\<highlight_report\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<if\>" start="[\[{]\s*\<if\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<import_assignments\>" start="[\[{]\s*\<import_assignments\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<incr\>" start="[\[{]\s*\<incr\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn keyword altera_stainfo contained a[rgs] b[ody] cm[dcount] comm[ands] comp[lete] d[efault] e[xists] g[lobals] h[ostname] le[vel] li[brary] loa[ded] loc[als] n[ameofexecutable] pa[tchlevel] pr[ocs] sc[ript] sh[aredlibextension] t[clversion] v[ars] 
hi! link altera_stainfo Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<info\>" start="[\[{]\s*\<info\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_stainfo

syn keyword altera_stainit_tk contained -h[] -he[lp] -l[ong_help] 
hi! link altera_stainit_tk Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<init_tk\>" start="[\[{]\s*\<init_tk\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_stainit_tk

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<initialize_ioo\>" start="[\[{]\s*\<initialize_ioo\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<initialize_sin\>" start="[\[{]\s*\<initialize_sin\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<interp\>" start="[\[{]\s*\<interp\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<is_dq_signal\>" start="[\[{]\s*\<is_dq_signal\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<is_dqs_signal\>" start="[\[{]\s*\<is_dqs_signal\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn keyword altera_stais_project_open contained -h[] -he[lp] -l[ong_help] 
hi! link altera_stais_project_open Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<is_project_open\>" start="[\[{]\s*\<is_project_open\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_stais_project_open

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<is_report_loaded\>" start="[\[{]\s*\<is_report_loaded\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<join\>" start="[\[{]\s*\<join\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<lappend\>" start="[\[{]\s*\<lappend\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<lassign\>" start="[\[{]\s*\<lassign\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<lindex\>" start="[\[{]\s*\<lindex\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<linsert\>" start="[\[{]\s*\<linsert\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<list\>" start="[\[{]\s*\<list\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<llength\>" start="[\[{]\s*\<llength\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn keyword altera_staload contained -h[] -he[lp] -l[ong_help] 
hi! link altera_staload Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<load\>" start="[\[{]\s*\<load\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staload

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<load_database\>" start="[\[{]\s*\<load_database\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn keyword altera_staload_package contained -h[] -he[lp] -l[ong_help] -v[ersion] 
hi! link altera_staload_package Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<load_package\>" start="[\[{]\s*\<load_package\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staload_package

syn keyword altera_staload_report contained -h[] -he[lp] -l[ong_help] -s[imulator] 
hi! link altera_staload_report Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<load_report\>" start="[\[{]\s*\<load_report\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staload_report

syn keyword altera_stalocate contained -ch[ip] -co[lor] -cp[s] -h[] -he[lp] -la[bel] -lo[ng_help] -r[pe] -t[mv] 
hi! link altera_stalocate Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<locate\>" start="[\[{]\s*\<locate\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_stalocate

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<lrange\>" start="[\[{]\s*\<lrange\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<lrepeat\>" start="[\[{]\s*\<lrepeat\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<lreplace\>" start="[\[{]\s*\<lreplace\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<lreverse\>" start="[\[{]\s*\<lreverse\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<lsearch\>" start="[\[{]\s*\<lsearch\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<lset\>" start="[\[{]\s*\<lset\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn keyword altera_stalsort contained -a[scii] -c[ommand] -de[creasing] -di[ctionary] -inc[reasing] -ind[ex] -int[eger] -r[eal] -u[nique] 
hi! link altera_stalsort Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<lsort\>" start="[\[{]\s*\<lsort\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_stalsort

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<msg_tcl_disable_msg_box\>" start="[\[{]\s*\<msg_tcl_disable_msg_box\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<msg_tcl_enable_eda_socket\>" start="[\[{]\s*\<msg_tcl_enable_eda_socket\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<msg_tcl_enable_msg_box\>" start="[\[{]\s*\<msg_tcl_enable_msg_box\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<msg_tcl_flush_stdout\>" start="[\[{]\s*\<msg_tcl_flush_stdout\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<msg_tcl_internal_error\>" start="[\[{]\s*\<msg_tcl_internal_error\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<msg_tcl_internal_error_display\>" start="[\[{]\s*\<msg_tcl_internal_error_display\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<msg_tcl_post_display\>" start="[\[{]\s*\<msg_tcl_post_display\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<msg_tcl_post_display_and_delete\>" start="[\[{]\s*\<msg_tcl_post_display_and_delete\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<msg_tcl_post_message\>" start="[\[{]\s*\<msg_tcl_post_message\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<msg_tcl_post_message_handle\>" start="[\[{]\s*\<msg_tcl_post_message_handle\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<msg_tcl_prompt_display\>" start="[\[{]\s*\<msg_tcl_prompt_display\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<msg_tcl_puts\>" start="[\[{]\s*\<msg_tcl_puts\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<msg_vdebug\>" start="[\[{]\s*\<msg_vdebug\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<namespace\>" start="[\[{]\s*\<namespace\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<native_puts\>" start="[\[{]\s*\<native_puts\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<non_sdc_in_sdc_file\>" start="[\[{]\s*\<non_sdc_in_sdc_file\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<open\>" start="[\[{]\s*\<open\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<open_timing_report\>" start="[\[{]\s*\<open_timing_report\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn keyword altera_stapackage contained f[orget] i[fneeded] n[ames] pre[sent] pro[vide] r[equire] u[nknown] vc[ompare] ve[rsions] vs[atisfies] 
hi! link altera_stapackage Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<package\>" start="[\[{]\s*\<package\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_stapackage

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<pid\>" start="[\[{]\s*\<pid\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<postMessage\>" start="[\[{]\s*\<postMessage\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn keyword altera_stapost_message contained -h[] -he[lp] -l[ong_help] -t[ype] 
hi! link altera_stapost_message Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<post_message\>" start="[\[{]\s*\<post_message\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_stapost_message

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<proc\>" start="[\[{]\s*\<proc\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn keyword altera_staproject_archive contained -a[ll_revisions] -h[] -he[lp] -include_l[ibraries] -include_o[utputs] -l[ong_help] -o[verwrite] -u[se_file_set] -v[ersion_compatible_database] 
hi! link altera_staproject_archive Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<project_archive\>" start="[\[{]\s*\<project_archive\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staproject_archive

syn keyword altera_staproject_close contained -d[ont_export_assignments] -h[] -he[lp] -l[ong_help] 
hi! link altera_staproject_close Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<project_close\>" start="[\[{]\s*\<project_close\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staproject_close

syn keyword altera_staproject_exists contained -h[] -he[lp] -l[ong_help] 
hi! link altera_staproject_exists Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<project_exists\>" start="[\[{]\s*\<project_exists\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staproject_exists

syn keyword altera_staproject_new contained -f[amily] -h[] -he[lp] -l[ong_help] -o[verwrite] -p[art] -r[evision] 
hi! link altera_staproject_new Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<project_new\>" start="[\[{]\s*\<project_new\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staproject_new

syn keyword altera_staproject_open contained -c[urrent_revision] -f[orce] -h[] -he[lp] -l[ong_help] -r[evision] 
hi! link altera_staproject_open Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<project_open\>" start="[\[{]\s*\<project_open\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staproject_open

syn keyword altera_staproject_restore contained -d[estination] -h[] -he[lp] -l[ong_help] -o[verwrite] -u[pdate_included_file_info] 
hi! link altera_staproject_restore Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<project_restore\>" start="[\[{]\s*\<project_restore\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staproject_restore

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<project_settings_exist\>" start="[\[{]\s*\<project_settings_exist\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<puts\>" start="[\[{]\s*\<puts\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<pwd\>" start="[\[{]\s*\<pwd\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<qeval\>" start="[\[{]\s*\<qeval\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn keyword altera_staqexec contained -h[] -he[lp] -l[ong_help] 
hi! link altera_staqexec Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<qexec\>" start="[\[{]\s*\<qexec\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staqexec

syn keyword altera_staqexit contained -e[rror] -h[] -he[lp] -l[ong_help] -s[uccess] 
hi! link altera_staqexit Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<qexit\>" start="[\[{]\s*\<qexit\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staqexit

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<qputs\>" start="[\[{]\s*\<qputs\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<qsta_stamp_generate_arc_name\>" start="[\[{]\s*\<qsta_stamp_generate_arc_name\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<qsta_write_stamp\>" start="[\[{]\s*\<qsta_write_stamp\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn keyword altera_staquery_collection contained -a[ll] -h[] -he[lp] -lim[it] -lis[t_format] -lo[ng_help] -r[eport_format] 
hi! link altera_staquery_collection Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<query_collection\>" start="[\[{]\s*\<query_collection\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staquery_collection

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<queue_simulation\>" start="[\[{]\s*\<queue_simulation\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<read\>" start="[\[{]\s*\<read\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<read_large_file\>" start="[\[{]\s*\<read_large_file\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn keyword altera_staread_sdc contained -h[] -hd[l] -he[lp] -l[ong_help] 
hi! link altera_staread_sdc Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<read_sdc\>" start="[\[{]\s*\<read_sdc\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staread_sdc

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<read_timing_netlist\>" start="[\[{]\s*\<read_timing_netlist\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn keyword altera_staread_xml_report contained -h[] -he[lp] -l[ong_help] 
hi! link altera_staread_xml_report Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<read_xml_report\>" start="[\[{]\s*\<read_xml_report\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staread_xml_report

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<regexp\>" start="[\[{]\s*\<regexp\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<register_tb_path\>" start="[\[{]\s*\<register_tb_path\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<regsub\>" start="[\[{]\s*\<regsub\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn keyword altera_staremove_all_global_assignments contained -e[ntity] -h[] -he[lp] -l[ong_help] -n[ame] -s[ection_id] -t[ag] 
hi! link altera_staremove_all_global_assignments Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<remove_all_global_assignments\>" start="[\[{]\s*\<remove_all_global_assignments\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staremove_all_global_assignments

syn keyword altera_staremove_all_instance_assignments contained -e[ntity] -f[rom] -h[] -he[lp] -l[ong_help] -n[ame] -s[ection_id] -ta[g] -to[] 
hi! link altera_staremove_all_instance_assignments Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<remove_all_instance_assignments\>" start="[\[{]\s*\<remove_all_instance_assignments\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staremove_all_instance_assignments

syn keyword altera_staremove_all_parameters contained -e[ntity] -h[] -he[lp] -l[ong_help] -n[ame] -ta[g] -to[] 
hi! link altera_staremove_all_parameters Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<remove_all_parameters\>" start="[\[{]\s*\<remove_all_parameters\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staremove_all_parameters

syn keyword altera_staremove_annotated_delay contained -a[ll] -h[] -he[lp] -l[ong_help] 
hi! link altera_staremove_annotated_delay Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<remove_annotated_delay\>" start="[\[{]\s*\<remove_annotated_delay\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staremove_annotated_delay

syn keyword altera_staremove_clock contained -a[ll] -h[] -he[lp] -l[ong_help] 
hi! link altera_staremove_clock Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<remove_clock\>" start="[\[{]\s*\<remove_clock\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staremove_clock

syn keyword altera_staremove_clock_groups contained -a[ll] -h[] -he[lp] -l[ong_help] 
hi! link altera_staremove_clock_groups Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<remove_clock_groups\>" start="[\[{]\s*\<remove_clock_groups\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staremove_clock_groups

syn keyword altera_staremove_clock_latency contained -h[] -he[lp] -l[ong_help] -s[ource] 
hi! link altera_staremove_clock_latency Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<remove_clock_latency\>" start="[\[{]\s*\<remove_clock_latency\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staremove_clock_latency

syn keyword altera_staremove_clock_uncertainty contained -f[rom] -h[] -he[lp] -l[ong_help] -t[o] 
hi! link altera_staremove_clock_uncertainty Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<remove_clock_uncertainty\>" start="[\[{]\s*\<remove_clock_uncertainty\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staremove_clock_uncertainty

syn keyword altera_staremove_disable_timing contained -f[rom] -h[] -he[lp] -l[ong_help] -t[o] 
hi! link altera_staremove_disable_timing Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<remove_disable_timing\>" start="[\[{]\s*\<remove_disable_timing\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staremove_disable_timing

syn keyword altera_staremove_from_collection contained -h[] -he[lp] -l[ong_help] 
hi! link altera_staremove_from_collection Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<remove_from_collection\>" start="[\[{]\s*\<remove_from_collection\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staremove_from_collection

syn keyword altera_staremove_input_delay contained -h[] -he[lp] -l[ong_help] 
hi! link altera_staremove_input_delay Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<remove_input_delay\>" start="[\[{]\s*\<remove_input_delay\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staremove_input_delay

syn keyword altera_staremove_output_delay contained -h[] -he[lp] -l[ong_help] 
hi! link altera_staremove_output_delay Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<remove_output_delay\>" start="[\[{]\s*\<remove_output_delay\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staremove_output_delay

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<rename\>" start="[\[{]\s*\<rename\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<rename_timing_report_panel\>" start="[\[{]\s*\<rename_timing_report_panel\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<report_advanced_io_power_for_pin\>" start="[\[{]\s*\<report_advanced_io_power_for_pin\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn keyword altera_stareport_advanced_io_timing contained -a[ppend] -f[ile] -h[] -he[lp] -l[ong_help] -p[anel_name] -s[tdout] 
hi! link altera_stareport_advanced_io_timing Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<report_advanced_io_timing\>" start="[\[{]\s*\<report_advanced_io_timing\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_stareport_advanced_io_timing

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<report_advanced_io_timing_for_pin\>" start="[\[{]\s*\<report_advanced_io_timing_for_pin\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn keyword altera_stareport_bottleneck contained -c[metric] -d[etails] -h[] -he[lp] -l[ong_help] -m[etric] -n[worst] -p[anel_name] -s[tdout] 
hi! link altera_stareport_bottleneck Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<report_bottleneck\>" start="[\[{]\s*\<report_bottleneck\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_stareport_bottleneck

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<report_bottleneck_internal\>" start="[\[{]\s*\<report_bottleneck_internal\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<report_bottleneck_num_fanins_metric\>" start="[\[{]\s*\<report_bottleneck_num_fanins_metric\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<report_bottleneck_num_fanouts_metric\>" start="[\[{]\s*\<report_bottleneck_num_fanouts_metric\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<report_bottleneck_num_fpaths_metric\>" start="[\[{]\s*\<report_bottleneck_num_fpaths_metric\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<report_bottleneck_num_paths_metric\>" start="[\[{]\s*\<report_bottleneck_num_paths_metric\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<report_bottleneck_test_metric\>" start="[\[{]\s*\<report_bottleneck_test_metric\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<report_bottleneck_tns_metric\>" start="[\[{]\s*\<report_bottleneck_tns_metric\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn keyword altera_stareport_clock_fmax_summary contained -a[ppend] -f[ile] -h[] -he[lp] -l[ong_help] -p[anel_name] -s[tdout] 
hi! link altera_stareport_clock_fmax_summary Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<report_clock_fmax_summary\>" start="[\[{]\s*\<report_clock_fmax_summary\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_stareport_clock_fmax_summary

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<report_clock_relationship\>" start="[\[{]\s*\<report_clock_relationship\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn keyword altera_stareport_clock_transfers contained -a[ppend] -f[ile] -h[] -he[lp] -ho[ld] -l[ong_help] -p[anel_name] -rec[overy] -rem[oval] -se[tup] -st[dout] 
hi! link altera_stareport_clock_transfers Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<report_clock_transfers\>" start="[\[{]\s*\<report_clock_transfers\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_stareport_clock_transfers

syn keyword altera_stareport_clocks contained -a[ppend] -d[esc] -f[ile] -h[] -he[lp] -l[ong_help] -p[anel_name] -st[dout] -su[mmary] -w[aveform] 
hi! link altera_stareport_clocks Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<report_clocks\>" start="[\[{]\s*\<report_clocks\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_stareport_clocks

syn keyword altera_stareport_datasheet contained -a[ppend] -e[xpand_bus] -f[ile] -h[] -he[lp] -l[ong_help] -p[anel_name] -s[tdout] 
hi! link altera_stareport_datasheet Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<report_datasheet\>" start="[\[{]\s*\<report_datasheet\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_stareport_datasheet

syn keyword altera_stareport_ddr contained -a[ppend] -f[ile] -h[] -he[lp] -l[ong_help] -p[anel_name] -s[tdout] 
hi! link altera_stareport_ddr Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<report_ddr\>" start="[\[{]\s*\<report_ddr\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_stareport_ddr

syn keyword altera_stareport_device_info contained -h[] -he[lp] -l[ong_help] 
hi! link altera_stareport_device_info Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<report_device_info\>" start="[\[{]\s*\<report_device_info\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_stareport_device_info

syn keyword altera_stareport_exceptions contained -a[ppend] -d[etail] -fall_f[rom_clock] -fall_t[o_clock] -fi[le] -from[] -from_[clock] -h[] -he[lp] -ho[ld] -le[ss_than_slack] -lo[ng_help] -np[aths] -nw[orst] -pai[rs_only] -pan[el_name] -rec[overy] -rem[oval] -rise_f[rom_clock] -rise_t[o_clock] -se[tup] -st[dout] -th[rough] -to[] -to_[clock] 
hi! link altera_stareport_exceptions Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<report_exceptions\>" start="[\[{]\s*\<report_exceptions\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_stareport_exceptions

syn keyword altera_stareport_family_info contained -h[] -he[lp] -l[ong_help] 
hi! link altera_stareport_family_info Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<report_family_info\>" start="[\[{]\s*\<report_family_info\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_stareport_family_info

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<report_fatal_talkback_error\>" start="[\[{]\s*\<report_fatal_talkback_error\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn keyword altera_stareport_max_skew contained -a[ppend] -d[etail] -f[ile] -h[] -he[lp] -le[ss_than_slack] -lo[ng_help] -n[paths] -p[anel_name] -sh[ow_routing] -st[dout] 
hi! link altera_stareport_max_skew Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<report_max_skew\>" start="[\[{]\s*\<report_max_skew\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_stareport_max_skew

syn keyword altera_stareport_metastability contained -a[ppend] -f[ile] -h[] -he[lp] -l[ong_help] -p[anel_name] -s[tdout] 
hi! link altera_stareport_metastability Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<report_metastability\>" start="[\[{]\s*\<report_metastability\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_stareport_metastability

syn keyword altera_stareport_min_pulse_width contained -a[ppend] -d[etail] -f[ile] -h[] -he[lp] -l[ong_help] -n[worst] -p[anel_name] -s[tdout] 
hi! link altera_stareport_min_pulse_width Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<report_min_pulse_width\>" start="[\[{]\s*\<report_min_pulse_width\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_stareport_min_pulse_width

syn keyword altera_stareport_net_delay contained -a[ppend] -f[ile] -h[] -he[lp] -l[ong_help] -n[worst] -p[anel_name] -s[tdout] 
hi! link altera_stareport_net_delay Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<report_net_delay\>" start="[\[{]\s*\<report_net_delay\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_stareport_net_delay

syn keyword altera_stareport_net_timing contained -a[ppend] -f[ile] -h[] -he[lp] -l[ong_help] -nworst_d[elay] -nworst_f[anout] -p[anel_name] -s[tdout] 
hi! link altera_stareport_net_timing Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<report_net_timing\>" start="[\[{]\s*\<report_net_timing\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_stareport_net_timing

syn keyword altera_stareport_part_info contained -h[] -he[lp] -l[ong_help] 
hi! link altera_stareport_part_info Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<report_part_info\>" start="[\[{]\s*\<report_part_info\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_stareport_part_info

syn keyword altera_stareport_partitions contained -h[] -he[lp] -l[ong_help] -n[worst] -p[anel_name] -s[tdout] 
hi! link altera_stareport_partitions Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<report_partitions\>" start="[\[{]\s*\<report_partitions\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_stareport_partitions

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<report_partitions_internal\>" start="[\[{]\s*\<report_partitions_internal\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn keyword altera_stareport_path contained -a[ppend] -fi[le] -fr[om] -h[] -he[lp] -l[ong_help] -m[in_path] -np[aths] -nw[orst] -pai[rs_only] -pan[el_name] -sh[ow_routing] -st[dout] -su[mmary] -th[rough] -to[] 
hi! link altera_stareport_path Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<report_path\>" start="[\[{]\s*\<report_path\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_stareport_path

syn keyword altera_stareport_rskm contained -a[ppend] -f[ile] -h[] -he[lp] -l[ong_help] -p[anel_name] -s[tdout] 
hi! link altera_stareport_rskm Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<report_rskm\>" start="[\[{]\s*\<report_rskm\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_stareport_rskm

syn keyword altera_stareport_sdc contained -a[ppend] -f[ile] -h[] -he[lp] -i[gnored] -l[ong_help] -p[anel_name] -s[tdout] 
hi! link altera_stareport_sdc Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<report_sdc\>" start="[\[{]\s*\<report_sdc\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_stareport_sdc

syn keyword altera_stareport_skew contained -a[ppend] -d[etail] -e[xclude] -fall_f[rom_clock] -fall_t[o_clock] -fi[le] -from[] -from_[clock] -g[reater_than_skew] -h[] -he[lp] -i[nclude] -l[ong_help] -n[paths] -p[anel_name] -rise_f[rom_clock] -rise_t[o_clock] -sh[ow_routing] -st[dout] -th[rough] -to[] -to_[clock] 
hi! link altera_stareport_skew Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<report_skew\>" start="[\[{]\s*\<report_skew\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_stareport_skew

syn keyword altera_stareport_tccs contained -a[ppend] -f[ile] -h[] -he[lp] -l[ong_help] -p[anel_name] -s[tdout] 
hi! link altera_stareport_tccs Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<report_tccs\>" start="[\[{]\s*\<report_tccs\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_stareport_tccs

syn keyword altera_stareport_timing contained -a[ppend] -d[etail] -fall_f[rom_clock] -fall_t[o_clock] -fals[e_path] -fi[le] -from[] -from_[clock] -h[] -he[lp] -ho[ld] -le[ss_than_slack] -lo[ng_help] -np[aths] -nw[orst] -pai[rs_only] -pan[el_name] -rec[overy] -rem[oval] -rise_f[rom_clock] -rise_t[o_clock] -se[tup] -sh[ow_routing] -st[dout] -th[rough] -to[] -to_[clock] 
hi! link altera_stareport_timing Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<report_timing\>" start="[\[{]\s*\<report_timing\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_stareport_timing

syn keyword altera_stareport_ucp contained -a[ppend] -f[ile] -h[] -he[lp] -l[ong_help] -p[anel_name] -st[dout] -su[mmary] 
hi! link altera_stareport_ucp Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<report_ucp\>" start="[\[{]\s*\<report_ucp\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_stareport_ucp

syn keyword altera_stareset_design contained -h[] -he[lp] -l[ong_help] 
hi! link altera_stareset_design Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<reset_design\>" start="[\[{]\s*\<reset_design\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_stareset_design

syn keyword altera_stareset_timing_derate contained -h[] -he[lp] -l[ong_help] 
hi! link altera_stareset_timing_derate Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<reset_timing_derate\>" start="[\[{]\s*\<reset_timing_derate\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_stareset_timing_derate

syn keyword altera_staresolve_file_path contained -h[] -he[lp] -l[ong_help] 
hi! link altera_staresolve_file_path Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<resolve_file_path\>" start="[\[{]\s*\<resolve_file_path\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staresolve_file_path

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<return\>" start="[\[{]\s*\<return\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn keyword altera_starevision_exists contained -h[] -he[lp] -l[ong_help] -p[roject] 
hi! link altera_starevision_exists Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<revision_exists\>" start="[\[{]\s*\<revision_exists\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_starevision_exists

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<revision_exists_internal\>" start="[\[{]\s*\<revision_exists_internal\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<run_simulations\>" start="[\[{]\s*\<run_simulations\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn keyword altera_stasave_report_database contained -h[] -he[lp] -l[ong_help] 
hi! link altera_stasave_report_database Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<save_report_database\>" start="[\[{]\s*\<save_report_database\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_stasave_report_database

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<scan\>" start="[\[{]\s*\<scan\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<seek\>" start="[\[{]\s*\<seek\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<set\>" start="[\[{]\s*\<set\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,ResVarName

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<set_acf_manager\>" start="[\[{]\s*\<set_acf_manager\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn keyword altera_staset_active_clocks contained -h[] -he[lp] -l[ong_help] 
hi! link altera_staset_active_clocks Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<set_active_clocks\>" start="[\[{]\s*\<set_active_clocks\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staset_active_clocks

syn keyword altera_staset_annotated_delay contained -c[ell] -ff[] -fr[] -fro[m] -h[] -he[lp] -l[ong_help] -ma[x] -mi[n] -n[et] -o[perating_conditions] -rf[] -rr[] -t[o] 
hi! link altera_staset_annotated_delay Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<set_annotated_delay\>" start="[\[{]\s*\<set_annotated_delay\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staset_annotated_delay

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<set_bit_settings\>" start="[\[{]\s*\<set_bit_settings\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<set_board_model_parameter\>" start="[\[{]\s*\<set_board_model_parameter\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<set_case_analysis\>" start="[\[{]\s*\<set_case_analysis\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<set_clock_gating_check\>" start="[\[{]\s*\<set_clock_gating_check\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn keyword altera_staset_clock_groups contained -a[synchronous] -e[xclusive] -g[roup] -h[] -he[lp] -l[ong_help] 
hi! link altera_staset_clock_groups Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<set_clock_groups\>" start="[\[{]\s*\<set_clock_groups\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staset_clock_groups

syn keyword altera_staset_clock_latency contained -c[lock] -e[arly] -f[all] -h[] -he[lp] -la[te] -lo[ng_help] -r[ise] -s[ource] 
hi! link altera_staset_clock_latency Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<set_clock_latency\>" start="[\[{]\s*\<set_clock_latency\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staset_clock_latency

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<set_clock_transition\>" start="[\[{]\s*\<set_clock_transition\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn keyword altera_staset_clock_uncertainty contained -a[dd] -fall_f[rom] -fall_t[o] -fr[om] -h[] -he[lp] -ho[ld] -l[ong_help] -rise_f[rom] -rise_t[o] -s[etup] -t[o] 
hi! link altera_staset_clock_uncertainty Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<set_clock_uncertainty\>" start="[\[{]\s*\<set_clock_uncertainty\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staset_clock_uncertainty

syn keyword altera_staset_current_revision contained -f[orce] -h[] -he[lp] -l[ong_help] 
hi! link altera_staset_current_revision Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<set_current_revision\>" start="[\[{]\s*\<set_current_revision\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staset_current_revision

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<set_current_strength\>" start="[\[{]\s*\<set_current_strength\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<set_data_check\>" start="[\[{]\s*\<set_data_check\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<set_decimal_places\>" start="[\[{]\s*\<set_decimal_places\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<set_delay_chain\>" start="[\[{]\s*\<set_delay_chain\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<set_device\>" start="[\[{]\s*\<set_device\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn keyword altera_staset_disable_timing contained -f[rom] -h[] -he[lp] -l[ong_help] -t[o] 
hi! link altera_staset_disable_timing Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<set_disable_timing\>" start="[\[{]\s*\<set_disable_timing\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staset_disable_timing

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<set_dll_loading\>" start="[\[{]\s*\<set_dll_loading\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<set_drive\>" start="[\[{]\s*\<set_drive\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<set_drive_strength\>" start="[\[{]\s*\<set_drive_strength\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<set_driving_cell\>" start="[\[{]\s*\<set_driving_cell\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn keyword altera_staset_false_path contained -fall_f[rom] -fall_t[o] -fr[om] -h[] -he[lp] -ho[ld] -l[ong_help] -rise_f[rom] -rise_t[o] -s[etup] -th[rough] -to[] 
hi! link altera_staset_false_path Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<set_false_path\>" start="[\[{]\s*\<set_false_path\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staset_false_path

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<set_fanout_load\>" start="[\[{]\s*\<set_fanout_load\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<set_file_lock\>" start="[\[{]\s*\<set_file_lock\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn keyword altera_staset_global_assignment contained -c[omment] -d[isable] -e[ntity] -h[] -he[lp] -l[ong_help] -n[ame] -r[emove] -s[ection_id] -t[ag] 
hi! link altera_staset_global_assignment Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<set_global_assignment\>" start="[\[{]\s*\<set_global_assignment\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staset_global_assignment

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<set_hc_assignments\>" start="[\[{]\s*\<set_hc_assignments\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<set_hierarchy_separator\>" start="[\[{]\s*\<set_hierarchy_separator\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<set_hssi_pin\>" start="[\[{]\s*\<set_hssi_pin\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<set_hssi_preemphasis_pretap\>" start="[\[{]\s*\<set_hssi_preemphasis_pretap\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<set_hssi_preemphasis_tap1\>" start="[\[{]\s*\<set_hssi_preemphasis_tap1\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<set_hssi_preemphasis_tap2\>" start="[\[{]\s*\<set_hssi_preemphasis_tap2\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<set_hssi_protocol\>" start="[\[{]\s*\<set_hssi_protocol\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<set_hssi_rx_common_mode\>" start="[\[{]\s*\<set_hssi_rx_common_mode\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<set_hssi_rx_dc_gain_setting\>" start="[\[{]\s*\<set_hssi_rx_dc_gain_setting\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<set_hssi_rx_equalizer_setting\>" start="[\[{]\s*\<set_hssi_rx_equalizer_setting\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<set_hssi_slew_rate\>" start="[\[{]\s*\<set_hssi_slew_rate\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<set_hssi_tx_common_mode\>" start="[\[{]\s*\<set_hssi_tx_common_mode\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<set_hssi_vod\>" start="[\[{]\s*\<set_hssi_vod\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<set_ini_var\>" start="[\[{]\s*\<set_ini_var\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn keyword altera_staset_input_delay contained -a[dd_delay] -clock[] -clock_[fall] -f[all] -h[] -he[lp] -l[ong_help] -ma[x] -mi[n] -re[ference_pin] -ri[se] -s[ource_latency_included] 
hi! link altera_staset_input_delay Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<set_input_delay\>" start="[\[{]\s*\<set_input_delay\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staset_input_delay

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<set_input_oct_impedance\>" start="[\[{]\s*\<set_input_oct_impedance\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn keyword altera_staset_input_transition contained -clock[] -clock_[fall] -f[all] -h[] -he[lp] -l[ong_help] -ma[x] -mi[n] -r[ise] 
hi! link altera_staset_input_transition Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<set_input_transition\>" start="[\[{]\s*\<set_input_transition\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staset_input_transition

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<set_input_transition_time\>" start="[\[{]\s*\<set_input_transition_time\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn keyword altera_staset_instance_assignment contained -c[omment] -d[isable] -e[ntity] -fa[ll] -fr[om] -h[] -he[lp] -l[ong_help] -n[ame] -re[move] -ri[se] -s[ection_id] -ta[g] -to[] 
hi! link altera_staset_instance_assignment Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<set_instance_assignment\>" start="[\[{]\s*\<set_instance_assignment\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staset_instance_assignment

syn keyword altera_staset_io_assignment contained -c[omment] -d[isable] -h[] -he[lp] -i[o_standard] -l[ong_help] -n[ame] -r[emove] -t[ag] 
hi! link altera_staset_io_assignment Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<set_io_assignment\>" start="[\[{]\s*\<set_io_assignment\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staset_io_assignment

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<set_io_standard\>" start="[\[{]\s*\<set_io_standard\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<set_load\>" start="[\[{]\s*\<set_load\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<set_location\>" start="[\[{]\s*\<set_location\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn keyword altera_staset_location_assignment contained -c[omment] -d[isable] -h[] -he[lp] -l[ong_help] -r[emove] -ta[g] -to[] 
hi! link altera_staset_location_assignment Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<set_location_assignment\>" start="[\[{]\s*\<set_location_assignment\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staset_location_assignment

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<set_logic_dc\>" start="[\[{]\s*\<set_logic_dc\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<set_logic_one\>" start="[\[{]\s*\<set_logic_one\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<set_logic_zero\>" start="[\[{]\s*\<set_logic_zero\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<set_max_area\>" start="[\[{]\s*\<set_max_area\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<set_max_capacitance\>" start="[\[{]\s*\<set_max_capacitance\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn keyword altera_staset_max_delay contained -fall_f[rom] -fall_t[o] -fr[om] -h[] -he[lp] -l[ong_help] -rise_f[rom] -rise_t[o] -th[rough] -to[] 
hi! link altera_staset_max_delay Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<set_max_delay\>" start="[\[{]\s*\<set_max_delay\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staset_max_delay

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<set_max_dynamic_power\>" start="[\[{]\s*\<set_max_dynamic_power\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<set_max_fanout\>" start="[\[{]\s*\<set_max_fanout\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<set_max_leakage_power\>" start="[\[{]\s*\<set_max_leakage_power\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn keyword altera_staset_max_skew contained -e[xclude] -fall_f[rom_clock] -fall_t[o_clock] -from[] -from_[clock] -h[] -he[lp] -i[nclude] -l[ong_help] -rise_f[rom_clock] -rise_t[o_clock] -th[rough] -to[] -to_[clock] 
hi! link altera_staset_max_skew Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<set_max_skew\>" start="[\[{]\s*\<set_max_skew\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staset_max_skew

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<set_max_time_borrow\>" start="[\[{]\s*\<set_max_time_borrow\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<set_max_transition\>" start="[\[{]\s*\<set_max_transition\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<set_min_capacitance\>" start="[\[{]\s*\<set_min_capacitance\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn keyword altera_staset_min_delay contained -fall_f[rom] -fall_t[o] -fr[om] -h[] -he[lp] -l[ong_help] -rise_f[rom] -rise_t[o] -th[rough] -to[] 
hi! link altera_staset_min_delay Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<set_min_delay\>" start="[\[{]\s*\<set_min_delay\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staset_min_delay

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<set_min_porosity\>" start="[\[{]\s*\<set_min_porosity\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn keyword altera_staset_multicycle_path contained -e[nd] -fall_f[rom] -fall_t[o] -fr[om] -h[] -he[lp] -ho[ld] -l[ong_help] -rise_f[rom] -rise_t[o] -se[tup] -st[art] -th[rough] -to[] 
hi! link altera_staset_multicycle_path Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<set_multicycle_path\>" start="[\[{]\s*\<set_multicycle_path\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staset_multicycle_path

syn keyword altera_staset_net_delay contained -f[rom] -h[] -he[lp] -l[ong_help] -ma[x] -mi[n] -t[o] 
hi! link altera_staset_net_delay Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<set_net_delay\>" start="[\[{]\s*\<set_net_delay\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staset_net_delay

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<set_oct_impedance\>" start="[\[{]\s*\<set_oct_impedance\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<set_open_drain\>" start="[\[{]\s*\<set_open_drain\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn keyword altera_staset_operating_conditions contained -f[orce_dat] -g[rade] -h[] -he[lp] -l[ong_help] -m[odel] -s[peed] -t[emperature] -v[oltage] 
hi! link altera_staset_operating_conditions Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<set_operating_conditions\>" start="[\[{]\s*\<set_operating_conditions\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staset_operating_conditions

syn keyword altera_staset_output_delay contained -a[dd_delay] -clock[] -clock_[fall] -f[all] -h[] -he[lp] -l[ong_help] -ma[x] -mi[n] -re[ference_pin] -ri[se] -s[ource_latency_included] 
hi! link altera_staset_output_delay Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<set_output_delay\>" start="[\[{]\s*\<set_output_delay\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staset_output_delay

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<set_output_oct_impedance\>" start="[\[{]\s*\<set_output_oct_impedance\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn keyword altera_staset_parameter contained -c[omment] -d[isable] -e[ntity] -h[] -he[lp] -l[ong_help] -n[ame] -r[emove] -ta[g] -to[] 
hi! link altera_staset_parameter Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<set_parameter\>" start="[\[{]\s*\<set_parameter\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staset_parameter

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<set_pin_direction\>" start="[\[{]\s*\<set_pin_direction\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<set_pin_location\>" start="[\[{]\s*\<set_pin_location\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<set_pin_name\>" start="[\[{]\s*\<set_pin_name\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<set_port_fanout_number\>" start="[\[{]\s*\<set_port_fanout_number\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn keyword altera_staset_power_file_assignment contained -h[] -he[lp] -l[ong_help] -r[emove] -sa[f_file] -se[ction_id] -t[o] -vcd_e[nd_time] -vcd_f[ile] -vcd_s[tart_time] 
hi! link altera_staset_power_file_assignment Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<set_power_file_assignment\>" start="[\[{]\s*\<set_power_file_assignment\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staset_power_file_assignment

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<set_preemphasis\>" start="[\[{]\s*\<set_preemphasis\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<set_project_mode\>" start="[\[{]\s*\<set_project_mode\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<set_project_settings\>" start="[\[{]\s*\<set_project_settings\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<set_propagated_clock\>" start="[\[{]\s*\<set_propagated_clock\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<set_qsf_mode\>" start="[\[{]\s*\<set_qsf_mode\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<set_quartus_array\>" start="[\[{]\s*\<set_quartus_array\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<set_ram_bus_hold\>" start="[\[{]\s*\<set_ram_bus_hold\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<set_resistance\>" start="[\[{]\s*\<set_resistance\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<set_revision_description\>" start="[\[{]\s*\<set_revision_description\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn keyword altera_staset_scc_mode contained -h[] -he[lp] -l[ong_help] -s[ize] -u[se_heuristic] 
hi! link altera_staset_scc_mode Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<set_scc_mode\>" start="[\[{]\s*\<set_scc_mode\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staset_scc_mode

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<set_slew_rate\>" start="[\[{]\s*\<set_slew_rate\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<set_tco_requirement\>" start="[\[{]\s*\<set_tco_requirement\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<set_termination\>" start="[\[{]\s*\<set_termination\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<set_th_requirement\>" start="[\[{]\s*\<set_th_requirement\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn keyword altera_staset_time_format contained -d[ecimal_places] -h[] -he[lp] -l[ong_help] -u[nit] 
hi! link altera_staset_time_format Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<set_time_format\>" start="[\[{]\s*\<set_time_format\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staset_time_format

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<set_time_unit\>" start="[\[{]\s*\<set_time_unit\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn keyword altera_staset_timing_derate contained -c[ell_delay] -e[arly] -h[] -he[lp] -la[te] -lo[ng_help] -n[et_delay] -o[perating_conditions] 
hi! link altera_staset_timing_derate Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<set_timing_derate\>" start="[\[{]\s*\<set_timing_derate\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staset_timing_derate

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<set_timing_report_folder\>" start="[\[{]\s*\<set_timing_report_folder\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<set_tpd_requirement\>" start="[\[{]\s*\<set_tpd_requirement\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<set_tsu_requirement\>" start="[\[{]\s*\<set_tsu_requirement\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn keyword altera_staset_user_option contained -h[] -he[lp] -l[ong_help] -n[ame] 
hi! link altera_staset_user_option Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<set_user_option\>" start="[\[{]\s*\<set_user_option\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staset_user_option

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<set_vod\>" start="[\[{]\s*\<set_vod\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<set_weak_pullup\>" start="[\[{]\s*\<set_weak_pullup\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<set_wire_load_min_block_size\>" start="[\[{]\s*\<set_wire_load_min_block_size\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<set_wire_load_mode\>" start="[\[{]\s*\<set_wire_load_mode\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<set_wire_load_model\>" start="[\[{]\s*\<set_wire_load_model\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<set_wire_selection_group\>" start="[\[{]\s*\<set_wire_selection_group\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<sh\>" start="[\[{]\s*\<sh\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=tclLineContinue,tclNumber,tclVarRef,tclString,tclComment,altera_stash

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<socket\>" start="[\[{]\s*\<socket\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<source\>" start="[\[{]\s*\<source\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<split\>" start="[\[{]\s*\<split\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn keyword altera_stastopwatch contained -h[] -he[lp] -la[p_time] -lo[ng_help] -n[umber_format] -r[eset] -s[tart] 
hi! link altera_stastopwatch Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<stopwatch\>" start="[\[{]\s*\<stopwatch\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_stastopwatch

syn keyword altera_stastring contained b[ytelength] c[ompare] e[qual] f[irst] in[dex] is[] la[st] le[ngth] map[] mat[ch] ra[nge] repe[at] repl[ace] tol[ower] tot[itle] tou[pper] trim[] triml[eft] trimr[ight] worde[nd] words[tart] 
hi! link altera_stastring Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<string\>" start="[\[{]\s*\<string\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_stastring

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<subst\>" start="[\[{]\s*\<subst\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn keyword altera_staswitch contained -e[xact] -g[lob] -r[egexp] 
hi! link altera_staswitch Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<switch\>" start="[\[{]\s*\<switch\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staswitch

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<tclLog\>" start="[\[{]\s*\<tclLog\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<tcl_findLibrary\>" start="[\[{]\s*\<tcl_findLibrary\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<tell\>" start="[\[{]\s*\<tell\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn keyword altera_statest_assignment_trait contained -h[] -he[lp] -l[ong_help] -n[ame] -t[rait] 
hi! link altera_statest_assignment_trait Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<test_assignment_trait\>" start="[\[{]\s*\<test_assignment_trait\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_statest_assignment_trait

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<test_device_trait_of\>" start="[\[{]\s*\<test_device_trait_of\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<test_family_trait_of\>" start="[\[{]\s*\<test_family_trait_of\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<test_part_trait_of\>" start="[\[{]\s*\<test_part_trait_of\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<then\>" start="[\[{]\s*\<then\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<time\>" start="[\[{]\s*\<time\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn keyword altera_statiming_netlist_exist contained -h[] -he[lp] -l[ong_help] 
hi! link altera_statiming_netlist_exist Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<timing_netlist_exist\>" start="[\[{]\s*\<timing_netlist_exist\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_statiming_netlist_exist

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<trace\>" start="[\[{]\s*\<trace\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<uninitialize_ioo\>" start="[\[{]\s*\<uninitialize_ioo\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<uninitialize_sin\>" start="[\[{]\s*\<uninitialize_sin\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<unknown\>" start="[\[{]\s*\<unknown\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<unknown_original\>" start="[\[{]\s*\<unknown_original\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<unload\>" start="[\[{]\s*\<unload\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<unload_database\>" start="[\[{]\s*\<unload_database\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn keyword altera_staunload_report contained -h[] -he[lp] -l[ong_help] 
hi! link altera_staunload_report Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<unload_report\>" start="[\[{]\s*\<unload_report\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staunload_report

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<unset\>" start="[\[{]\s*\<unset\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<update\>" start="[\[{]\s*\<update\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn keyword altera_staupdate_timing_netlist contained -f[ull] -h[] -he[lp] -l[ong_help] 
hi! link altera_staupdate_timing_netlist Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<update_timing_netlist\>" start="[\[{]\s*\<update_timing_netlist\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staupdate_timing_netlist

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<uplevel\>" start="[\[{]\s*\<uplevel\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,tcltkCommandForEval

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<upvar\>" start="[\[{]\s*\<upvar\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn keyword altera_stause_timequest_style_escaping contained -h[] -he[lp] -l[ong_help] -of[f] -on[] 
hi! link altera_stause_timequest_style_escaping Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<use_timequest_style_escaping\>" start="[\[{]\s*\<use_timequest_style_escaping\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_stause_timequest_style_escaping

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<variable\>" start="[\[{]\s*\<variable\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<vwait\>" start="[\[{]\s*\<vwait\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<webhelp_display_topic\>" start="[\[{]\s*\<webhelp_display_topic\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<while\>" start="[\[{]\s*\<while\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<write_partition_edge_slack_stats\>" start="[\[{]\s*\<write_partition_edge_slack_stats\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn keyword altera_stawrite_report_panel contained -f[ile] -h[] -he[lp] -ht[ml] -i[d] -l[ong_help] -n[ame] -x[ml] 
hi! link altera_stawrite_report_panel Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<write_report_panel\>" start="[\[{]\s*\<write_report_panel\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_stawrite_report_panel

syn keyword altera_stawrite_sdc contained -e[xpand] -h[] -he[lp] -hi[story] -l[ong_help] 
hi! link altera_stawrite_sdc Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<write_sdc\>" start="[\[{]\s*\<write_sdc\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_stawrite_sdc

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<write_timing_netlist\>" start="[\[{]\s*\<write_timing_netlist\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<write_timing_report\>" start="[\[{]\s*\<write_timing_report\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn keyword altera_stawrite_xml_report contained -h[] -he[lp] -l[ong_help] 
hi! link altera_stawrite_xml_report Special
syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<write_xml_report\>" start="[\[{]\s*\<write_xml_report\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_stawrite_xml_report

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<xibiso_add_model\>" start="[\[{]\s*\<xibiso_add_model\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<xibiso_get_header\>" start="[\[{]\s*\<xibiso_get_header\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<xibiso_get_model\>" start="[\[{]\s*\<xibiso_get_model\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<xibiso_get_model_name\>" start="[\[{]\s*\<xibiso_get_model_name\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<xibiso_init\>" start="[\[{]\s*\<xibiso_init\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<xibiso_init_header\>" start="[\[{]\s*\<xibiso_init_header\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster

syn region tcltkCommand matchgroup=tcltkCommandColor   start="^\s*\<xibiso_read_model\>" start="[\[{]\s*\<xibiso_read_model\>"hs=s+1  matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster



" Special handling for eval commands (allow following commands to syntax)
if altera_sta_syntax_enable_eval
  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<add_cmd_to_tcl_table_menu\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<add_ddr_report_command\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<add_row_to_table\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staadd_row_to_table contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<add_timing_summary_data\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<add_to_collection\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staadd_to_collection contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<add_to_recent_projects\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<add_to_recent_projects_internal\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<after\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<all_clocks\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staall_clocks contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<all_inputs\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staall_inputs contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<all_outputs\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staall_outputs contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<all_registers\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staall_registers contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<append\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<apply\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<array\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staarray contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<assignment_group\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staassignment_group contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<auto_execok\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<auto_import\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<auto_load\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<auto_load_index\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<auto_mkindex\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<auto_mkindex_old\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<auto_qualify\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<auto_reset\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<binary\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<break\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<build_tcl_table_cmd\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<case\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<catch\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<cd\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<chan\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<check_timing\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_stacheck_timing contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<checksum\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_stachecksum contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<clock\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<close\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<close_timing_report\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<concat\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<continue\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<copy_project\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<copy_project_for_hardcopy\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<create_clock\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_stacreate_clock contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<create_generated_clock\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_stacreate_generated_clock contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<create_pin_object\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<create_report_histogram\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_stacreate_report_histogram contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<create_report_panel\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_stacreate_report_panel contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<create_revision\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_stacreate_revision contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<create_slack_histogram\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_stacreate_slack_histogram contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<create_test_collection\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<create_timequest_summary\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<create_timing_database\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<create_timing_netlist\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_stacreate_timing_netlist contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<create_timing_summary\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_stacreate_timing_summary contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<current_design\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<current_instance\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<define_proc_attributes\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_stadefine_proc_attributes contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<delete_folder\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<delete_report_panel\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_stadelete_report_panel contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<delete_revision\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_stadelete_revision contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<delete_timing_netlist\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_stadelete_timing_netlist contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<delete_timing_report_panel\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<derive_clock_uncertainty\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staderive_clock_uncertainty contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<derive_clocks\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staderive_clocks contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<derive_lvds_clocks\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<derive_pll_clocks\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staderive_pll_clocks contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<destroy_pin_object\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<dict\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<disable_msg_box\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<disable_natural_bus_naming\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_stadisable_natural_bus_naming contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<disable_natural_bus_naming_internal\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<echo_time\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<else\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<elseif\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<enable_ccpp_removal\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staenable_ccpp_removal contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<enable_msg_box\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<enable_natural_bus_naming\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staenable_natural_bus_naming contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<enable_natural_bus_naming_internal\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<enable_sdc_extension_collections\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staenable_sdc_extension_collections contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<encoding\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<enumerate_family_traits\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<eof\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<error\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<escape_brackets\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staescape_brackets contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<escape_brackets_internal\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<exec\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<execute_assignment_batch\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staexecute_assignment_batch contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<exit\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<export_assignment_files\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<export_assignments\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staexport_assignments contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<expr\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staexpr contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<fblocked\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<fconfigure\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<fcopy\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<file\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_stafile contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<fileevent\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<find_intersection\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<flush\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<for\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<foreach\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<foreach_in_collection\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<format\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<get_acf_info\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<get_acf_manager\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<get_all_assignment_names\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staget_all_assignment_names contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<get_all_assignments\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staget_all_assignments contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<get_all_global_assignments\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staget_all_global_assignments contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<get_all_instance_assignments\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staget_all_instance_assignments contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<get_all_parameters\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staget_all_parameters contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<get_all_quartus_defaults\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staget_all_quartus_defaults contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<get_all_user_option_names\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staget_all_user_option_names contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<get_assignment_groups\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staget_assignment_groups contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<get_assignment_info\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staget_assignment_info contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<get_assignment_name_info\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staget_assignment_name_info contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<get_assignments_for_name_id\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<get_available_operating_conditions\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staget_available_operating_conditions contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<get_bit_settings\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<get_board_model_parameter\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<get_board_model_parameter_list\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<get_cell_info\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staget_cell_info contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<get_cells\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staget_cells contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<get_clock_domain_info\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staget_clock_domain_info contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<get_clock_fmax_info\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staget_clock_fmax_info contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<get_clock_info\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staget_clock_info contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<get_clock_list\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<get_clocks\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staget_clocks contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<get_collection_by_name\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<get_collection_info\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<get_collection_size\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staget_collection_size contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<get_current_revision\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staget_current_revision contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<get_current_sta_report_folder\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<get_current_strength\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<get_current_strength_list\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<get_current_timequest_report_folder\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<get_datasheet\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staget_datasheet contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<get_datasheet_report_panel_name\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<get_default_sdc_file_names\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staget_default_sdc_file_names contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<get_delay_chain\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<get_delay_info\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<get_dq_width\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<get_dstr_string\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<get_edge_info\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staget_edge_info contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<get_edge_slacks\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staget_edge_slacks contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<get_environment_info\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staget_environment_info contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<get_family_info\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<get_family_list\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staget_family_list contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<get_fanins\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staget_fanins contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<get_fanouts\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staget_fanouts contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<get_file_info\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<get_files\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<get_fitter_resource_usage\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staget_fitter_resource_usage contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<get_global_assignment\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staget_global_assignment contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<get_ini_file\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<get_ini_var\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<get_input_timing_results\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<get_instance_assignment\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staget_instance_assignment contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<get_io_standard\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<get_io_standard_list\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<get_keepers\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staget_keepers contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<get_lib_cells\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<get_lib_pins\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<get_libraries\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<get_libs\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<get_license_xml\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<get_location\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<get_location_assignment\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staget_location_assignment contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<get_max_skew_default_include_list\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<get_min_pulse_width\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staget_min_pulse_width contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<get_name_info\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staget_name_info contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<get_names\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_sta_attributes,altera_staget_names contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<get_net_info\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staget_net_info contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<get_nets\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staget_nets contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<get_node_clock_list\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<get_node_info\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staget_node_info contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<get_nodes\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staget_nodes contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<get_number_of_columns\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staget_number_of_columns contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<get_number_of_rows\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staget_number_of_rows contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<get_object_info\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staget_object_info contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<get_oct_impedance\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<get_oct_impedance_list\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<get_open_drain\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<get_operating_conditions\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staget_operating_conditions contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<get_operating_conditions_info\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staget_operating_conditions_info contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<get_output_enable_results\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<get_parameter\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staget_parameter contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<get_part_info\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staget_part_info contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<get_part_list\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staget_part_list contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<get_partition_info\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staget_partition_info contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<get_partitions\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staget_partitions contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<get_path\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staget_path contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<get_path_info\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staget_path_info contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<get_pin_count\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<get_pin_direction\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<get_pin_info\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staget_pin_info contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<get_pin_location\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<get_pin_location_list\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<get_pin_name\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<get_pins\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staget_pins contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<get_pins_from_gid\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<get_point_info\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staget_point_info contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<get_port_info\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staget_port_info contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<get_ports\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staget_ports contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<get_preemphasis\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<get_project_directory\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staget_project_directory contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<get_project_license_status\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<get_project_revisions\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staget_project_revisions contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<get_project_settings\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<get_quartus_legal_string\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<get_ram_bus_hold\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<get_register_info\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staget_register_info contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<get_registers\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staget_registers contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<get_report_folder\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<get_report_panel_column_index\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staget_report_panel_column_index contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<get_report_panel_data\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staget_report_panel_data contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<get_report_panel_id\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staget_report_panel_id contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<get_report_panel_names\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staget_report_panel_names contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<get_report_panel_row\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staget_report_panel_row contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<get_report_panel_row_index\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staget_report_panel_row_index contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<get_reserved_type\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<get_revision_description\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<get_simulation_results\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<get_slack_information_for_partitions\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<get_slew_rate\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<get_temperature_option\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<get_termination\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<get_timing_analysis_summary_results\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staget_timing_analysis_summary_results contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<get_timing_info\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<get_timing_paths\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staget_timing_paths contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<get_top_level_entity\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staget_top_level_entity contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<get_user_option\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staget_user_option contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<get_vod\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<get_weak_pullup\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<gets\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<glob\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<global\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,ResVarName contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<help\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<highlight_report\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<if\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<import_assignments\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<incr\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<info\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_stainfo contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<init_tk\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_stainit_tk contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<initialize_ioo\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<initialize_sin\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<interp\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<is_dq_signal\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<is_dqs_signal\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<is_project_open\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_stais_project_open contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<is_report_loaded\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<join\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<lappend\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<lassign\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<lindex\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<linsert\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<list\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<llength\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<load\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staload contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<load_database\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<load_package\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staload_package contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<load_report\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staload_report contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<locate\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_stalocate contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<lrange\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<lrepeat\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<lreplace\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<lreverse\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<lsearch\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<lset\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<lsort\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_stalsort contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<msg_tcl_disable_msg_box\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<msg_tcl_enable_eda_socket\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<msg_tcl_enable_msg_box\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<msg_tcl_flush_stdout\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<msg_tcl_internal_error\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<msg_tcl_internal_error_display\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<msg_tcl_post_display\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<msg_tcl_post_display_and_delete\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<msg_tcl_post_message\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<msg_tcl_post_message_handle\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<msg_tcl_prompt_display\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<msg_tcl_puts\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<msg_vdebug\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<namespace\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<native_puts\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<non_sdc_in_sdc_file\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<open\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<open_timing_report\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<package\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_stapackage contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<pid\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<postMessage\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<post_message\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_stapost_message contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<proc\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<project_archive\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staproject_archive contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<project_close\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staproject_close contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<project_exists\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staproject_exists contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<project_new\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staproject_new contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<project_open\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staproject_open contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<project_restore\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staproject_restore contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<project_settings_exist\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<puts\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<pwd\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<qeval\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<qexec\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staqexec contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<qexit\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staqexit contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<qputs\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<qsta_stamp_generate_arc_name\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<qsta_write_stamp\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<query_collection\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staquery_collection contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<queue_simulation\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<read\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<read_large_file\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<read_sdc\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staread_sdc contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<read_timing_netlist\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<read_xml_report\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staread_xml_report contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<regexp\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<register_tb_path\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<regsub\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<remove_all_global_assignments\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staremove_all_global_assignments contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<remove_all_instance_assignments\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staremove_all_instance_assignments contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<remove_all_parameters\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staremove_all_parameters contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<remove_annotated_delay\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staremove_annotated_delay contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<remove_clock\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staremove_clock contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<remove_clock_groups\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staremove_clock_groups contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<remove_clock_latency\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staremove_clock_latency contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<remove_clock_uncertainty\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staremove_clock_uncertainty contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<remove_disable_timing\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staremove_disable_timing contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<remove_from_collection\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staremove_from_collection contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<remove_input_delay\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staremove_input_delay contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<remove_output_delay\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staremove_output_delay contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<rename\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<rename_timing_report_panel\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<report_advanced_io_power_for_pin\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<report_advanced_io_timing\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_stareport_advanced_io_timing contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<report_advanced_io_timing_for_pin\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<report_bottleneck\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_stareport_bottleneck contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<report_bottleneck_internal\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<report_bottleneck_num_fanins_metric\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<report_bottleneck_num_fanouts_metric\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<report_bottleneck_num_fpaths_metric\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<report_bottleneck_num_paths_metric\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<report_bottleneck_test_metric\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<report_bottleneck_tns_metric\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<report_clock_fmax_summary\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_stareport_clock_fmax_summary contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<report_clock_relationship\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<report_clock_transfers\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_stareport_clock_transfers contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<report_clocks\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_stareport_clocks contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<report_datasheet\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_stareport_datasheet contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<report_ddr\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_stareport_ddr contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<report_device_info\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_stareport_device_info contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<report_exceptions\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_stareport_exceptions contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<report_family_info\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_stareport_family_info contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<report_fatal_talkback_error\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<report_max_skew\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_stareport_max_skew contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<report_metastability\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_stareport_metastability contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<report_min_pulse_width\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_stareport_min_pulse_width contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<report_net_delay\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_stareport_net_delay contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<report_net_timing\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_stareport_net_timing contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<report_part_info\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_stareport_part_info contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<report_partitions\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_stareport_partitions contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<report_partitions_internal\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<report_path\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_stareport_path contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<report_rskm\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_stareport_rskm contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<report_sdc\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_stareport_sdc contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<report_skew\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_stareport_skew contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<report_tccs\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_stareport_tccs contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<report_timing\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_stareport_timing contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<report_ucp\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_stareport_ucp contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<reset_design\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_stareset_design contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<reset_timing_derate\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_stareset_timing_derate contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<resolve_file_path\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staresolve_file_path contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<return\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<revision_exists\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_starevision_exists contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<revision_exists_internal\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<run_simulations\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<save_report_database\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_stasave_report_database contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<scan\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<seek\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<set\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,ResVarName contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<set_acf_manager\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<set_active_clocks\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staset_active_clocks contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<set_annotated_delay\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staset_annotated_delay contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<set_bit_settings\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<set_board_model_parameter\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<set_case_analysis\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<set_clock_gating_check\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<set_clock_groups\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staset_clock_groups contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<set_clock_latency\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staset_clock_latency contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<set_clock_transition\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<set_clock_uncertainty\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staset_clock_uncertainty contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<set_current_revision\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staset_current_revision contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<set_current_strength\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<set_data_check\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<set_decimal_places\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<set_delay_chain\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<set_device\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<set_disable_timing\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staset_disable_timing contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<set_dll_loading\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<set_drive\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<set_drive_strength\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<set_driving_cell\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<set_false_path\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staset_false_path contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<set_fanout_load\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<set_file_lock\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<set_global_assignment\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staset_global_assignment contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<set_hc_assignments\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<set_hierarchy_separator\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<set_hssi_pin\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<set_hssi_preemphasis_pretap\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<set_hssi_preemphasis_tap1\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<set_hssi_preemphasis_tap2\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<set_hssi_protocol\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<set_hssi_rx_common_mode\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<set_hssi_rx_dc_gain_setting\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<set_hssi_rx_equalizer_setting\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<set_hssi_slew_rate\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<set_hssi_tx_common_mode\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<set_hssi_vod\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<set_ini_var\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<set_input_delay\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staset_input_delay contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<set_input_oct_impedance\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<set_input_transition\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staset_input_transition contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<set_input_transition_time\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<set_instance_assignment\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staset_instance_assignment contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<set_io_assignment\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staset_io_assignment contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<set_io_standard\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<set_load\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<set_location\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<set_location_assignment\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staset_location_assignment contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<set_logic_dc\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<set_logic_one\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<set_logic_zero\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<set_max_area\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<set_max_capacitance\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<set_max_delay\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staset_max_delay contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<set_max_dynamic_power\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<set_max_fanout\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<set_max_leakage_power\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<set_max_skew\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staset_max_skew contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<set_max_time_borrow\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<set_max_transition\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<set_min_capacitance\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<set_min_delay\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staset_min_delay contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<set_min_porosity\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<set_multicycle_path\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staset_multicycle_path contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<set_net_delay\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staset_net_delay contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<set_oct_impedance\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<set_open_drain\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<set_operating_conditions\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staset_operating_conditions contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<set_output_delay\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staset_output_delay contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<set_output_oct_impedance\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<set_parameter\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staset_parameter contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<set_pin_direction\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<set_pin_location\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<set_pin_name\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<set_port_fanout_number\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<set_power_file_assignment\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staset_power_file_assignment contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<set_preemphasis\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<set_project_mode\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<set_project_settings\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<set_propagated_clock\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<set_qsf_mode\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<set_quartus_array\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<set_ram_bus_hold\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<set_resistance\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<set_revision_description\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<set_scc_mode\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staset_scc_mode contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<set_slew_rate\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<set_tco_requirement\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<set_termination\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<set_th_requirement\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<set_time_format\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staset_time_format contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<set_time_unit\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<set_timing_derate\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staset_timing_derate contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<set_timing_report_folder\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<set_tpd_requirement\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<set_tsu_requirement\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<set_user_option\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staset_user_option contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<set_vod\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<set_weak_pullup\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<set_wire_load_min_block_size\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<set_wire_load_mode\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<set_wire_load_model\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<set_wire_selection_group\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<sh\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=tclLineContinue,tclNumber,tclVarRef,tclString,tclComment,altera_stash contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<socket\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<source\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<split\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<stopwatch\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_stastopwatch contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<string\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_stastring contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<subst\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<switch\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staswitch contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<tclLog\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<tcl_findLibrary\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<tell\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<test_assignment_trait\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_statest_assignment_trait contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<test_device_trait_of\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<test_family_trait_of\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<test_part_trait_of\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<then\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<time\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<timing_netlist_exist\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_statiming_netlist_exist contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<trace\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<uninitialize_ioo\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<uninitialize_sin\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<unknown\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<unknown_original\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<unload\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<unload_database\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<unload_report\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staunload_report contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<unset\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<update\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<update_timing_netlist\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_staupdate_timing_netlist contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<upvar\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<use_timequest_style_escaping\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_stause_timequest_style_escaping contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<variable\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<vwait\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<webhelp_display_topic\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<while\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<write_partition_edge_slack_stats\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<write_report_panel\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_stawrite_report_panel contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<write_sdc\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_stawrite_sdc contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<write_timing_netlist\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<write_timing_report\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<write_xml_report\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster,altera_stawrite_xml_report contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<xibiso_add_model\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<xibiso_get_header\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<xibiso_get_model\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<xibiso_get_model_name\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<xibiso_init\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<xibiso_init_header\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained

  syn region tcltkCommandForEval matchgroup=tcltkCommandColor start="\<xibiso_read_model\>" matchgroup=NONE skip="^\s*$" end="[;\]]\|[^\\]$"me=e,he=e-1 contains=@altera_stacontainscluster contained


endif


" Load any local files
runtime syntax/altera_sta*local*.vim

" Bram would prefer this were in the ftplugin/pt.vim file, but that requires
" an extra step for installation.  Instead, just put the command to load
" the dictionary files here.
" get path to this script
if ! exists("altera_sta_syntax_dict_loaded")
  let altera_sta_syntax_dict_loaded = "0"
endif
if ! altera_sta_syntax_dict_loaded
  let s:mypath = expand("<sfile>:p:h") 
  " change backslash to forward slash
  let s:mypathfs = substitute(s:mypath,'\\','/','g')
  " set the complete command, escaping spaces 3 times (why 3? because that's what works!)
  exe "setlocal complete+=k" . escape(escape(escape(s:mypathfs,' '),' '),' ') . "/altera_sta*.dict"
  let altera_sta_syntax_dict_loaded = "1"
endif

hi! link ResVarRef Structure
hi! link ResVarName Structure

hi! link tclNumber		Number
"hi! link Bus		Number " Uncomment to see what matches as a Bus
hi! link tclString		String
hi! link tclComment		Comment
hi! link tclTodo		        Todo
hi! link tcltkCommandColor	Statement
hi! link tclLineContinue       WarningMsg
hi! link tclVarRef             Identifier
